<?php

namespace Teknisa\FIS\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;


class Fis57000FichaConteudoImportacaoFactory {

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function limpaDadosApurados($cdfilial, $nrmapafci) {
        $sql = "DELETE FROM ITMAPAFCI
                WHERE CDFILIAL = :P_CDFILIAL
                AND NRMAPAFCI = :P_NRMAPAFCI";
                
        $std = $this->connection->prepare($sql);
        
        $params = array('P_CDFILIAL' => $cdfilial,
                        'P_NRMAPAFCI' => $nrmapafci);
                        
        $std->execute($params);
    }
    
    public function buscaDadosApuracao($cdfilial, $dtinicial, $dtfinal) {
        $sql = "SELECT PA.CDSUBPRODETA AS CDPRODUTOOP, PR1.CDARVPROD, PR1.NMPRODUTO,
                PR1.SGUNIDADE, OP.NRORDPROD, OP.NRSUBORDPROD, PA.QTPRACABADO AS
                QTPRODUZIDA, L.CDPRODUTO AS CDPRODINSUMO, PR.CDARVPROD, PR.NMPRODUTO,
                L.NRLOTEESTQ, L.NRSUBLOTE, IT.NRLANCESTQ, IT.DTLANCMOVI, L.DSLANCESTQ,
                IP.CDFILIAL, IP.NRLANCTONF, IP.NRSEQITPROD, IP.VRUNITITEM
                FROM ORDPRODUCAO OP INNER JOIN PRODACABADO PA
                ON OP.CDFILIAL = PA.CDFILIAL
                AND OP.NRORDPROD = PA.NRORDPROD
                AND OP.NRSUBORDPROD = PA.NRSUBORDPROD
                INNER JOIN PRODUTO PR1
                ON PA.CDSUBPRODETA = PR1.CDPRODUTO
                INNER JOIN RETIRADAESTO R
                ON OP.CDFILIAL = R.CDFILIAL
                AND OP.NRORDPROD = R.NRORDPROD
                AND OP.NRSUBORDPROD = R.NRSUBORDPROD
                AND R.NRLANCESTQ IS NOT NULL
                INNER JOIN ITEMRETIEST I
                ON R.CDFILIAL = I.CDFILIAL
                AND R.NRRETEST = I.NRRETEST
                INNER JOIN LOTITRETIEST L
                ON I.CDFILIAL = L.CDFILIAL
                AND I.NRRETEST = L.NRRETEST
                AND I.CDPRODUTO = L.CDPRODUTO
                AND I.NRSEQRETPROD = L.NRSEQRETPROD
                AND L.IDTPRETEST = 'R'
                INNER JOIN PRODUTO PR
                ON L.CDPRODUTO = PR.CDPRODUTO
                INNER JOIN ITLANCTOEST IT
                ON L.CDFILIAL = IT.CDFILIMOVI
                AND L.CDPRODUTO = IT.CDPRODUTO
                AND L.NRLOTEESTQ = IT.NRLOTEESTQ
                AND L.NRSUBLOTE = IT.NRSUBLOTE
                INNER JOIN LANCTOESTOQ L
                ON IT.CDFILIAL = L.CDFILIAL
                AND IT.NRLANCESTQ = L.NRLANCESTQ
                INNER JOIN NOTAFISCAL NF
                ON L.CDFILIAL = NF.CDFILIAL
                AND L.NRLANCTONF = NF.NRLANCTONF
                INNER JOIN ITEMPRODUTO IP
                ON NF.CDFILIAL = IP.CDFILIAL
                AND NF.NRLANCTONF = IP.NRLANCTONF
                AND IT.CDPRODMOVI = IP.CDPRODMOVI
                AND IT.NRLOTEESTQ = IP.NRLOTEESTQ
                AND IT.NRSUBLOTE = IP.NRSUBLOTE,
                (SELECT DIGITO1CST FROM DIGITOCST WHERE IDCSTIFCI = 'S') CST
                WHERE OP.CDFILIAL = :P_CDFILIAL
                AND TO_DATE(OP.DTHRFIMREAOP) BETWEEN TO_DATE(:P_DTINICIAL) AND
                TO_DATE(:P_DTFINAL)
                AND OP.IDSITORDPROD = '3'
                AND IT.IDTIPOMOVI = '2'
                AND SUBSTR(IP.CDSITUTRIBPR, 1, 1) = CST.DIGITO1CST";
                
        $std = $this->connection->prepare($sql);
        
        $params = array('P_CDFILIAL' => $cdfilial,
                        'P_DTINICIAL' => $dtinicial,
                        'P_DTFINAL' => $dtfinal);
                        
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function insereDadosApurados($cdfilialfci, $nrmapafci, $nrseqitmapafci, $cdprodutoop, $nrordprod, $nrsubordprod, $qtproduzida, $cdprodinsumo, $nrloteestq, $nrsublote, $cdfilial, $nrlanctonf, $nrseqitprod, $vrunititem) {
        $sql = "INSERT INTO ITMAPAFCI
                (CDFILIALFCI, NRMAPAFCI, NRSEQITMAPAFCI, CDPRODUTOOP, NRORDPROD,
                NRSUBORDPROD, QTPRODUZIDA, CDPRODINSUMO, NRLOTEESTQ, NRSUBLOTE,
                CDFILIAL, NRLANCTONF, NRSEQITPROD, VRUNITITEM)
                VALUES
                (:CDFILIALFCI, :NRMAPAFCI, :NRSEQITMAPAFCI, :CDPRODUTOOP, :NRORDPROD,
                :NRSUBORDPROD, :QTPRODUZIDA, :CDPRODINSUMO, :NRLOTEESTQ, :NRSUBLOTE,
                :CDFILIAL, :NRLANCTONF, :NRSEQITPROD, :VRUNITITEM)";
                
        $std = $this->connection->prepare($sql);
        
        $params = array('CDFILIALFCI' => $cdfilialfci,
                        'NRMAPAFCI' => $nrmapafci,
                        'NRSEQITMAPAFCI' => $nrseqitmapafci,
                        'CDPRODUTOOP' => $cdprodutoop,
                        'NRORDPROD' => $nrordprod,
                        'NRSUBORDPROD' => $nrsubordprod,
                        'QTPRODUZIDA' => $qtproduzida,
                        'CDPRODINSUMO' => $cdprodinsumo,
                        'NRLOTEESTQ' => $nrloteestq,
                        'NRSUBLOTE' => $nrsublote,
                        'CDFILIAL' => $cdfilial,
                        'NRLANCTONF' => $nrlanctonf,
                        'NRSEQITPROD' => $nrseqitprod,
                        'VRUNITITEM' => $vrunititem);
                        
        $std->execute($params);
    }
}