<?php

namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Doctrine\ORM\EntityManager;


class Fis75000EfdReinfFactory{
    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    // Verifica se ja existe o evento pelo prestador/tomador
    public function verificaEventoServicos($cdempresa, $dtmescompetenc, $nrevento, $cdestabreinf, $nrinsjurfili) {
        $params = array(
            "CDEMPRESA" => $cdempresa,
            "DTMESCOMPETENC"=>$dtmescompetenc,
            "NREVENTO" => $nrevento,
            "CDESTABREINF" => $cdestabreinf,
            "NRINSJURFILI" => $nrinsjurfili
        );
        $sql = "SELECT *
                  FROM ENVIOEVENTOREINF
                WHERE CDEMPRESA    = :CDEMPRESA
                  AND DTMESCOMPETENC = :DTMESCOMPETENC
                  AND NREVENTO       = :NREVENTO
                  AND CDESTABREINF   = :CDESTABREINF
                  AND IDSTATUS IN ('C', 'M', 'P', 'E')
                  AND NVL(NRINSJURFILI,'N')   = NVL(:NRINSJURFILI,'N')";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function verificaEventoPeriodo($nrevento, $dtmescompetenc) {
        $params = array(
            "NREVENTO" => $nrevento,
            "DTMESCOMPETENC" => $dtmescompetenc
        );
        $sql = "SELECT * FROM ENVIOEVENTOREINF WHERE NREVENTO = :NREVENTO AND DTMESCOMPETENC = :DTMESCOMPETENC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getParamReinf($cdempresa) {
        $params = array(
            "CDEMPRESA" => $cdempresa
        );
        $sql = "SELECT * FROM PARAMEMPREINF WHERE CDEMPRESA = :CDEMPRESA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function verificaEventoServicosPeriodo($cdempresa, $dtmescompetenc, $nrevento) {
        $params = array(
            "CDEMPRESA" => $cdempresa,
            "DTMESCOMPETENC" => $dtmescompetenc,
            "NREVENTO" => $nrevento
        );
        $sql = "SELECT * FROM ENVIOEVENTOREINF WHERE CDEMPRESA = :CDEMPRESA AND DTMESCOMPETENC = :DTMESCOMPETENC AND NREVENTO = :NREVENTO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function updateSituacaoEvento($idStatus, $dataEnvio, $nrenvio, $dsobservacao, $id, $recibo, $dtcompsemmovto, $dtresposta = null, $dsdirxmlconsulta = null) {
        $params = array(
            "IDSTATUS"         => $idStatus,
            "DTENVIO"          => $dataEnvio,
            "DSOBSERVACAO"     => $dsobservacao,
            "IDEVENTO"         => $id,
            "NRRECIBO"         => $recibo,
            "NRENVIO"          => $nrenvio,
            "DTCOMPSEMMOVTO"   => $dtcompsemmovto,
            "DTRESPOSTA"       => $dtresposta,
            "DSDIRXMLCONSULTA" => $dsdirxmlconsulta
        );
        
        $sql = "UPDATE ENVIOEVENTOREINF
                   SET IDSTATUS         = :IDSTATUS,
                       DTENVIO          = :DTENVIO,
                       DSOBSERVACAO     = :DSOBSERVACAO,
                       IDEVENTO         = :IDEVENTO,
                       NRRECIBO         = :NRRECIBO,
                       DTCOMPSEMMOVTO   = :DTCOMPSEMMOVTO,
                       DTRESPOSTA       = :DTRESPOSTA,
                       DSDIRXMLCONSULTA = :DSDIRXMLCONSULTA
                WHERE NRENVIO         = :NRENVIO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function verificaR2099Reaberto($id, $nrRecibo, $idStatus) {
        $params = array(
            "IDEVENTO"      => $id,
            "NRRECIBO"      => $nrRecibo,
            "IDSTATUS"      => $idStatus
        );
        $sql = "SELECT * FROM
                    ENVIOEVENTOREINF
                WHERE
                    IDEVENTO     = :IDEVENTO
                    AND NRRECIBO = :NRRECIBO
                    AND IDSTATUS = :IDSTATUS";
                    
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($params);
        
        return $std->fetch();
        
    }
    
    public function verificaR2098Reaberto($cdEmpresa, $dtmescompetenc) {
        $params = array(
            "CDEMPRESA"         => $cdEmpresa,
            "DTMESCOMPETENC"    => $dtmescompetenc
        );
        
        $sql = "SELECT * 
                    FROM ENVIOEVENTOREINF ER,
                    EVENTOREINF EV
                    WHERE CDEMPRESA = :CDEMPRESA 
                    AND DTMESCOMPETENC = :DTMESCOMPETENC
                    AND EV.NMEVENTO = 'R-2098'
                    AND ER.NREVENTO = EV.NREVENTO";
                    
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($params);
        
        return $std->fetch();
        
    }
    
    public function getMapaPeriodo($cdempresa, $dtinicial, $dtfinal, $cdimposto) {
        $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_DTINICIAL" => $dtinicial,
            "P_DTFINAL"   => $dtfinal,
            "P_CDIMPOSTO" => $cdimposto
        );
        $sql =  "SELECT NRSEQUMAPAPU
                FROM MAPAAPURAC
                WHERE CDIMPOSTO = :P_CDIMPOSTO
                    AND CDEMPRESA = :P_CDEMPRESA
                    AND DTINIPERIODO = :P_DTINICIAL
                    AND DTFIMPERIODO = :P_DTFINAL";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($params);
        
        return $std->fetch();
        
    }
    
    //Busca todos fornecedores ou clientes referentes a  uma mapa de determinado período.
    public function getParticipantesMapa($nrsequmapapu, $imposto) {
        $params = array(
            "P_NRSEQUMAPAPU" => $nrsequmapapu,
            "P_CDIMPOSTO" => $imposto
        );
        $sql =  "SELECT DISTINCT FO.CDFORNECED AS CDESTABREINF, (CASE WHEN :P_CDIMPOSTO = '26' THEN F.NRINSJURFILI ELSE '' END) AS NRINSJURFILI
                FROM NOTAFISCAL N,
                  IMPOSTONF I,
                  FORNECEDOR FO,
                  FILIAL F
                WHERE N.CDFILIAL   = I.CDFILIAL
                AND N.NRLANCTONF   = I.NRLANCTONF
                AND ((I.NRSEQUMAPAPU = :P_NRSEQUMAPAPU)
                OR (I.NRSEQMAPOIMP   = :P_NRSEQUMAPAPU))
                AND FO.CDFORNECED  = N.CDFORNECED
                AND N.NRORG        = I.NRORG
                AND FO.NRORG       = N.NRORG
                AND ((VRIMPOSTONF > 0 AND I.CDFISCALNF = '1') 
                OR (:P_CDIMPOSTO = '26'))
                AND DECODE(N.IDENTRSAIDOP, 'E', N.CDFILIRECE,N.CDFILIEMIT) = F.CDFILIAL
                UNION ALL
                SELECT DISTINCT CL.CDCLIENTE, (CASE WHEN :P_CDIMPOSTO = '26' THEN F.NRINSJURFILI ELSE '' END) AS NRINSJURFILI
                FROM NOTAFISCAL N,
                  IMPOSTONF I,
                  CLIENTE CL,
                  FILIAL F
                WHERE N.CDFILIAL     = I.CDFILIAL
                AND N.NRLANCTONF     = I.NRLANCTONF
                AND ((I.NRSEQUMAPAPU = :P_NRSEQUMAPAPU)
                OR (I.NRSEQMAPOIMP   = :P_NRSEQUMAPAPU))
                AND CL.CDCLIENTE     = N.CDCLIENTE
                AND N.NRORG          = I.NRORG
                AND CL.NRORG         = N.NRORG
                AND ((VRIMPOSTONF > 0 AND I.CDFISCALNF = '1') 
                OR (:P_CDIMPOSTO = '26'))
                AND DECODE(N.IDENTRSAIDOP, 'E', N.CDFILIRECE,N.CDFILIEMIT) = F.CDFILIAL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio) {
         $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_NREVENTO"  => $nrevento,
            "P_NRENVIO"   => $nrenvio,
        );
        $sql =  "DELETE FROM ARQEFD_REINF
                WHERE NREVENTO = :P_NREVENTO
                    AND CDEMPRESA = :P_CDEMPRESA
                    AND NRENVIO = :P_NRENVIO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    // Função que verifica se os seguintes eventos foram enviados no periodo . 
    //EXCETO OS EVENTOS R2030 E R2050 que atulamente não estão sendo implementados.
    public function verificaMovimentecaoPeriodo($cdempresa, $dsversao, $dtmescompetenc) {
        $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_DSVERSAO" => $dsversao,
            "P_DTMESCOMPETENC" => $dtmescompetenc
        );
        $sql =  "SELECT(
                    CASE
                    WHEN (R.EVTSERVTM ='N'
                        AND R.EVTSERVPR='N'
                        AND R.EVTASSDESPREP ='N'
                        AND R.EVTCPRB ='N'
                        AND R.EVTPGTOS ='N') THEN
                    'N'
                    ELSE 'S' END) AS MOVIMENTACAO
                    FROM 
                    (SELECT EVT.NMEVENTO,
                         'N' AS EXISTE
                    FROM EVENTOREINF EVT
                    WHERE NOT EXISTS 
                        (SELECT 1
                        FROM ENVIOEVENTOREINF ENV
                        WHERE ENV.NREVENTO = EVT.NREVENTO
                                AND ENV.CDEMPRESA = :P_CDEMPRESA
                                AND ENV.DTMESCOMPETENC = :P_DTMESCOMPETENC
                                AND IDSTATUS = 'M'-- STATUS EM PROCESSAMENTO
                                AND ENV.DSVERSAO = EVT.DSVERSAO)
                                AND EVT.DSVERSAO = :P_DSVERSAO
                                AND EVT.NMEVENTO IN ('R-2010', 'R-2020', 'R-2040', 'R-2060', 'R-2070')
                        UNION
                        SELECT EVT.NMEVENTO,
                         'S' AS EXISTE
                        FROM EVENTOREINF EVT, ENVIOEVENTOREINF ENV
                        WHERE EVT.DSVERSAO = :P_DSVERSAO
                                AND EVT.NMEVENTO IN ('R-2010', 'R-2020', 'R-2040', 'R-2060', 'R-2070')
                                AND ENV.NREVENTO = EVT.NREVENTO
                                AND ENV.CDEMPRESA = :P_CDEMPRESA
                                AND ENV.DTMESCOMPETENC = :P_DTMESCOMPETENC
                                AND IDSTATUS ='M' -- STATUS EM PROCESSAMENTO
                                AND ENV.DSVERSAO = EVT.DSVERSAO ) E PIVOT (MAX(EXISTE) FOR NMEVENTO IN ('R-2010' AS EVTSERVTM,'R-2020' AS EVTSERVPR,'R-2040' AS EVTASSDESPREP,'R-2060' AS EVTCPRB, 'R-2070'AS EVTPGTOS)) R";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function verificaMaiorDataSemMovimentacao($cdempresa, $nrvento, $dtmescompetenc) {
        $params = array(
            "CDEMPRESA" => $cdempresa,
            "NRVENTO" => $nrvento,
            "DTMESCOMPETENC" => $dtmescompetenc
        );
        $sql =  "SELECT MAX (DTCOMPSEMMOVTO) AS DTCOMPSEMMOVTO
                FROM
                  (SELECT DTCOMPSEMMOVTO
                  FROM ENVIOEVENTOREINF
                  WHERE CDEMPRESA    = :CDEMPRESA
                  AND IDSTATUS       !='P'
                  AND NREVENTO       = :NRVENTO
                  AND DTMESCOMPETENC < :DTMESCOMPETENC
                  )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getEnvio($nrenvio) {
        $params = array(
            "NRENVIO" => $nrenvio
        );
        $sql =  "SELECT * FROM ENVIOEVENTOREINF WHERE NRENVIO = :NRENVIO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getItensDeNota($params) {
        $sql = "SELECT CDARVPROD,
                  NMPRODUTO,
                  VRBRUTO,
                  SUM(VRBASE)     AS VRBASE ,
                  SUM(VRRETENCAO) AS VRRETENCAO,
                  CDCLASERVMOBEMP,
                  DSCLASERVMOBEMP,
                  NRORG
                FROM
                  (SELECT PA.CDARVPROD,
                    PA.NMPRODUTO,
                    NF.CDINSCMUNI,
                    (IP.VRBRUTITEM)                            AS VRBRUTO,
                    (DECODE(IT.CDFISCALIT,'1',VRBASECALCIT,0)) AS VRBASE,
                    (DECODE(IT.CDFISCALIT,'1',VRIMPOSTOIT,0))  AS VRRETENCAO,
                    (SELECT C.CDCLASERVMOBEMP
                    FROM CLASERVMOBEMPR C
                    WHERE C.CDCLASERVMOBEMP               = PA.CDCLASERVMOBEMP
                    AND NVL(PA.CDINSCMUNI, NF.CDINSCMUNI) = NF.CDINSCMUNI
                    ) AS CDCLASERVMOBEMP,
                    (SELECT DSCLASERVMOBEMP
                    FROM CLASERVMOBEMPR C
                    WHERE C.CDCLASERVMOBEMP               = PA.CDCLASERVMOBEMP
                    AND NVL(PA.CDINSCMUNI, NF.CDINSCMUNI) = NF.CDINSCMUNI
                    ) AS DSCLASERVMOBEMP,
                    IP.NRORG
                  FROM ITEMPRODUTO IP,
                    ITEMPROIMPOS IT,
                    NOTAFISCAL NF,
                    IMPOSTO IM,
                    (SELECT DISTINCT PARAM.CDPRODSERV,
                      PARAM.CDEMPRESA,
                      PARAM.CDINSCMUNI,
                      PARAM.CDCLASERVMOBEMP,
                      PR.CDARVPROD,
                      PR.NMPRODUTO,
                      PR.CDPRODUTO
                    FROM PARAMMUNISERV PARAM,
                      PRODUTO PR
                    WHERE PARAM.IDDECLARACAO(+) = 'RE'
                    AND PARAM.CDEMPRESA(+)  = :CDEMPRESA
                    AND PARAM.CDINSCMUNI(+) = :CDINSCMUNI
                    AND PR.CDPRODUTO        = PARAM.CDPRODSERV(+)
                    ) PA
                  WHERE NF.CDFILIAL      = :CDFILIAL
                  AND IT.NRLANCTONF      = :NRLANCTONF
                  AND IT.CDFILIAL        = IP.CDFILIAL
                  AND IT.NRLANCTONF      = IP.NRLANCTONF
                  AND IT.NRSEQITPROD     = IP.NRSEQITPROD
                  AND PA.CDPRODUTO       = IP.CDPRODUTO
                  AND NF.CDFILIAL        = IP.CDFILIAL
                  AND NF.NRLANCTONF      = IP.NRLANCTONF
                  AND IM.CDIMPOSTO       = IT.CDIMPOSTO
                  AND IM.CDIMPOSTONFE    = :CDIMPOSTO
                  AND NF.CDEMPRESA       = :CDEMPRESA
                  AND NF.CDINSCMUNI     = :CDINSCMUNI
                  AND IT.CDFISCALIT      = '1'
                  AND VRIMPOSTOIT        > 0
                  )
                GROUP BY CDARVPROD,
                  NMPRODUTO,
                  VRBRUTO,
                  CDCLASERVMOBEMP,
                  DSCLASERVMOBEMP,
                  NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getR2099ParaReabrir($params) {
        $sql = "SELECT NRENVIO
                FROM ENVIOEVENTOREINF EN
                  JOIN EVENTOREINF EV
                  ON EV.NMEVENTO        = 'R-2099'
                  AND EV.NREVENTO       = EN.NREVENTO
                WHERE EN.CDEMPRESA    = :CDEMPRESA
                  AND EN.DTMESCOMPETENC = :DTMESCOMPETENC
                  AND EN.IDAMBIENTE = :IDAMBIENTE
                  AND EN.NRRECIBO IS NOT NULL
                  AND EN.IDSTATUS IN ('C', 'M', 'E')";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    } 
    
    public function updateEventoExcluido($nrenvio, $idstatus, $dsobservacao) {
        $params = array(
            "IDSTATUS"       => $idstatus,
            "DSOBSERVACAO"   => $dsobservacao,
            "NRENVIO"        => $nrenvio
        );
        $sql = "UPDATE ENVIOEVENTOREINF
                   SET IDSTATUS       = :IDSTATUS,
                       DSOBSERVACAO   = :DSOBSERVACAO
                WHERE NRENVIO         = :NRENVIO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function R1000Vigente($params) {
        // Função alterada para poder pegar apenas o R1000 vigente (IDSTATUS          IN ('M', 'C'))
        $sql =  "SELECT EN.NRORG,
                      EN.NRENVIO,
                      EN.CDEMPRESA,
                      EN.DTMESCOMPETENC,
                      EN.IDEVENTO,
                      EN.IDOPERACAO,
                      EN.DTENVIO,
                      EN.IDSTATUS,
                      EN.IDAMBIENTE,
                      EN.DTINIVALIDADE,
                      EN.DTFINVALIDADE
                    FROM ENVIOEVENTOREINF EN,
                      EVENTOREINF EV
                    WHERE EN.NREVENTO      = EV.NREVENTO
                    AND EN.DSVERSAO        = EV.DSVERSAO
                    AND EN.CDEMPRESA       = :CDEMPRESA
                    AND EV.NMEVENTO        = 'R-1000'
                    AND EN.IDAMBIENTE      = :IDAMBIENTE
                    AND NRENVIOEXCLUSAO   IS NULL
                    AND EN.DTINIVALIDADE  >= :DTINICIAL
                    AND IDSTATUS          IN ('M', 'C')
                    AND EN.IDOPERACAO      = 'I'
                    AND (EN.DTFINVALIDADE <= :DTFINAL
                    OR EN.DTFINVALIDADE   IS NULL
                    OR :DTFINAL         IS NULL)
                    ORDER BY DTINIVALIDADE DESC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosConsulta($nrenvio) {
        $params = array('NRENVIO' => $nrenvio);
        // Consulta para produção
        $sql = "SELECT DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')                         AS FISICOJURIDICO,
                  DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR) AS CODIGO,
                  NRRECIBO
                FROM EMPRESA E,
                  ENVIOEVENTOREINF ENVIO
                WHERE NRENVIO = :NRENVIO
                AND E.CDEMPRESA = ENVIO.CDEMPRESA";
        
        // Consulta para montar dados usando certificado da Teknisa Software
        // $sql = "SELECT DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')                         AS FISICOJURIDICO,
        //           DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS CODIGO,
        //           NRRECIBO
        //         FROM EMPRESA E,
        //           ENVIOEVENTOREINF ENVIO
        //         WHERE NRENVIO = :NRENVIO
        //         AND E.CDEMPRESA = ENVIO.CDEMPRESA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosConsulta2010($cdempresa, $dtinicial, $nrenvio, $nrsequmapapu) {
        $params = array( 
            'CDEMPRESA'     => $cdempresa,
            'DTINICIAL'     => $dtinicial,
            'NRENVIO'       => $nrenvio,
            'NRSEQUMAPAPU'  => $nrsequmapapu
        );
        
        // Consulta para montar dados para consulta do envio do evento R2010
        
        $sql = "SELECT  
                    ER.NMEVENTO                                                                     AS TIPOEVENTO,
                    TO_CHAR(TO_DATE(:DTINICIAL),'YYYY-MM')                                          AS PERAPUR,
                    DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')                                      AS TPINSC,
                    DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8),'F',E.NRINSJUREMPR)        AS NRINSC,
                    MAX(CASE
                        WHEN PR.CDCNO IS NULL THEN '1'
                        ELSE '4'
                    END)                                                                            AS TPINSCESTAB,
                    MAX(CASE
                        WHEN PR.CDCNO IS NOT NULL THEN PR.CDCNO
                        ELSE FI.NRINSJURFILI
                    END)                                                                            AS NRINSCESTAB, 
                    MAX(PR.IDSERVOBRCCIVIL)                                                         AS INDOBRA, 	
                    MAX(DECODE(PR.IDSERVOBRCCIVIL,'2',PR.CDCNO,FO.NRINSJURFORN) )                   AS CNPJPRESTADOR 
                FROM
                    NOTAFISCAL NF,
                    IMPOSTONF IP,
                    PARAMEMPREINF P,
                    ENVIOEVENTOREINF EV,
                    EVENTOREINF ER,
                    IMPOSTO IM,
                    IMPOSTONFE IE,
                    FORNECEDOR FO,
                    EMPRESA E,
                    FILIAL FI,
                    (
                        SELECT
                            SUM(DECODE(IT.CDFISCALIT,'1',VRIMPOSTOIT,0) ) AS VRIMPOSTOIT,
                            SUM(DECODE(IT.CDFISCALIT,'1',VRBASECALCIT,0) ) AS VRBASECALCIT,
                            SUM(VRCONTITIMP) AS VRCONTABOBRA,
                            IT.CDFILIAL,
                            IT.NRLANCTONF,
                            PR.IDSERVOBRCCIVIL,
                            PR.CDCNO
                        FROM
                            ITEMPRODUTO P,
                            IMPOSTO I,
                            ITEMPROIMPOS IT,
                            PARAMMUNISERV PR,
                            NOTAFISCAL NF
                        WHERE
                            P.CDFILIAL = IT.CDFILIAL
                            AND P.NRLANCTONF = IT.NRLANCTONF
                            AND P.NRSEQITPROD = IT.NRSEQITPROD
                            AND PR.CDEMPRESA = :CDEMPRESA
                            AND PR.CDPRODSERV = P.CDPRODUTO
                            AND I.CDIMPOSTO = IT.CDIMPOSTO
                            AND I.CDIMPOSTONFE = '41'
                            AND PR.CDEMPRESA = :CDEMPRESA
                            AND NF.CDFILIAL = IT.CDFILIAL
                            AND NF.NRLANCTONF = IT.NRLANCTONF
                            AND NF.NRLANCTONF = P.NRLANCTONF
                            AND NF.CDFILIAL = P.CDFILIAL
                            AND PR.CDINSCMUNI = NF.CDINSCMUNI
                            AND PR.IDDECLARACAO = 'RE'
                            AND PR.IDENTRSAIDOP IN (
                                'E',
                                'T'
                            )
                        GROUP BY
                            IT.CDFILIAL,
                            IT.NRLANCTONF,
                            PR.IDSERVOBRCCIVIL,
                            PR.CDCNO
                    ) PR
                WHERE
                    IP.CDFILIAL = NF.CDFILIAL
                    AND IP.NRLANCTONF = NF.NRLANCTONF
                    AND NF.CDEMPRESA = E.CDEMPRESA
                    AND NF.IDORIGDESTNF = 'F'
                    AND NF.CDEMPRESA = :CDEMPRESA
                    AND NF.CDFORNECED = FO.CDFORNECED
                    AND ( ( IP.NRSEQUMAPAPU = :NRSEQUMAPAPU )
                          OR ( IP.NRSEQMAPOIMP = :NRSEQUMAPAPU ) )
                    AND IE.CDIMPOSTONFE = IM.CDIMPOSTONFE
                    AND IP.CDIMPOSTO = IM.CDIMPOSTO
                    AND IP.CDFISCALNF = '1'
                    AND IP.VRIMPOSTONF > 0
                    AND IE.CDIMPOSTONFE = '41'
                    AND P.CDEMPRESA (+) = E.CDEMPRESA
                    AND PR.CDFILIAL = NF.CDFILIAL
                    AND PR.NRLANCTONF = NF.NRLANCTONF
                    AND EV.NRENVIO = :NRENVIO
                    AND EV.NREVENTO = ER.NREVENTO
                    AND EV.CDESTABREINF = NF.CDFORNECED
                    AND FI.CDFILIAL = NF.CDFILIRECE
                GROUP BY
                    ER.NMEVENTO,
                    TO_CHAR(TO_DATE(:DTINICIAL),'YYYY-MM'),
                    DECODE(E.IDTPIJUREMPR,'J','1','F','2',' '),
                    DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8),'F',E.NRINSJUREMPR)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosConsulta2020($cdempresa, $dtinicial, $nrenvio, $nrsequmapapu) {
        $params = array( 
            'CDEMPRESA'     => $cdempresa,
            'DTINICIAL'     => $dtinicial,
            'NRENVIO'       => $nrenvio,
            'NRSEQUMAPAPU'  => $nrsequmapapu
        );
        
        // Consulta para montar dados para consulta do envio do evento R2010
        
        $sql = "SELECT
                     ER.NMEVENTO   AS TIPOEVENTO,
                     TO_CHAR(TO_DATE(:DTINICIAL),'YYYY-MM') AS PERAPUR,
                     DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                     DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8),'F',E.NRINSJUREMPR) AS NRINSC,
                     CASE
                         WHEN PR.CDCNO IS NULL THEN '1'
                         ELSE '4'
                     END AS TPINSCESTABPREST,
                     CASE
                         WHEN PR.CDCNO IS NOT NULL THEN PR.CDCNO
                         ELSE E.NRINSJUREMPR
                     END AS NRINSCESTABPREST,
                     CASE
                         WHEN PR.CDCNO IS NULL THEN '1'
                         ELSE '4'
                     END AS TPINSCTOMADOR,
                     CASE
                         WHEN PR.CDCNO IS NOT NULL THEN PR.CDCNO
                         ELSE CL.NRINSJURCLIE
                     END AS NRINSCTOMADOR
                 FROM
                     NOTAFISCAL NF,
                     IMPOSTONF IP,
                     PARAMEMPREINF P,
                     ENVIOEVENTOREINF EV,
                     EVENTOREINF ER,
                     IMPOSTO IM,
                     IMPOSTONFE IE,
                     CLIENTE CL,
                     EMPRESA E,
                     (
                         SELECT
                             SUM(DECODE(IT.CDFISCALIT,'1',VRIMPOSTOIT,0) ) AS VRIMPOSTOIT,
                             SUM(DECODE(IT.CDFISCALIT,'1',VRBASECALCIT,0) ) AS VRBASECALCIT,
                             SUM(VRCONTITIMP) AS VRCONTABOBRA,
                             IT.CDFILIAL,
                             IT.NRLANCTONF,
                             PR.IDSERVOBRCCIVIL,
                             PR.CDCNO
                         FROM
                             ITEMPRODUTO P,
                             IMPOSTO I,
                             ITEMPROIMPOS IT,
                             PARAMMUNISERV PR,
                             NOTAFISCAL NF
                         WHERE
                             P.CDFILIAL = IT.CDFILIAL
                             AND P.NRLANCTONF = IT.NRLANCTONF
                             AND P.NRSEQITPROD = IT.NRSEQITPROD
                             AND PR.CDPRODSERV = P.CDPRODUTO
                             AND I.CDIMPOSTO = IT.CDIMPOSTO
                             AND I.CDIMPOSTONFE = '42'
                             AND PR.CDEMPRESA =:CDEMPRESA
                             AND NF.CDFILIAL = IT.CDFILIAL
                             AND NF.NRLANCTONF = IT.NRLANCTONF
                             AND NF.NRLANCTONF = P.NRLANCTONF
                             AND NF.CDFILIAL = P.CDFILIAL
                             AND PR.CDINSCMUNI = NF.CDINSCMUNI
                             AND PR.IDDECLARACAO = 'RE'
                             AND PR.IDENTRSAIDOP IN (
                                 'S',
                                 'T'
                             )
                         GROUP BY
                             IT.CDFILIAL,
                             IT.NRLANCTONF,
                             PR.IDSERVOBRCCIVIL,
                             PR.CDCNO
                     ) PR
                 WHERE
                     IP.CDFILIAL = NF.CDFILIAL
                     AND IP.NRLANCTONF = NF.NRLANCTONF
                     AND NF.CDEMPRESA = E.CDEMPRESA
                     AND NF.IDORIGDESTNF = 'C'
                     AND NF.CDEMPRESA =:CDEMPRESA
                     AND NF.CDCLIENTE = CL.CDCLIENTE
                     AND ( ( IP.NRSEQUMAPAPU =:NRSEQUMAPAPU )
                           OR ( IP.NRSEQMAPOIMP =:NRSEQUMAPAPU ) )
                     AND IE.CDIMPOSTONFE = IM.CDIMPOSTONFE
                     AND IP.CDIMPOSTO = IM.CDIMPOSTO
                     AND IP.CDFISCALNF = '1'
                     AND IP.VRIMPOSTONF > 0
                     AND IE.CDIMPOSTONFE = '42'
                     AND P.CDEMPRESA (+) = E.CDEMPRESA
                     AND PR.CDFILIAL (+) = NF.CDFILIAL
                     AND PR.NRLANCTONF (+) = NF.NRLANCTONF
                     AND EV.NRENVIO =:NRENVIO
                     AND EV.NREVENTO = ER.NREVENTO
                     AND EV.CDESTABREINF = NF.CDCLIENTE
                 GROUP BY
                     ER.NMEVENTO,
                     TO_CHAR(TO_DATE(:DTINICIAL),'YYYY-MM'),
                     DECODE(E.IDTPIJUREMPR,'J','1','F','2',' '),
                     DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8),'F',E.NRINSJUREMPR),
                     CASE
                         WHEN PR.CDCNO IS NULL THEN '1'
                         ELSE '4'
                     END,
                     CASE
                         WHEN PR.CDCNO IS NOT NULL THEN PR.CDCNO
                         ELSE E.NRINSJUREMPR
                     END,
                     CASE
                         WHEN PR.CDCNO IS NULL THEN '1'
                         ELSE '4'
                     END,
                     CASE
                         WHEN PR.CDCNO IS NOT NULL THEN PR.CDCNO
                         ELSE CL.NRINSJURCLIE
                     END";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosConsulta2055($cdempresa, $dtinicial, $nrenvio, $nrsequmapapu) {
        $params = array( 
            'CDEMPRESA'     => $cdempresa,
            'DTINICIAL'     => $dtinicial,
            'NRENVIO'       => $nrenvio,
            'NRSEQUMAPAPU'  => $nrsequmapapu
        );
        
        // Consulta para montar dados para consulta do envio do evento R2055
        
        $sql = "SELECT ER.NMEVENTO AS TIPOEVENTO,
                          DECODE(E.IDTPIJUREMPR,'J','1','F','2','') AS TPINSC,
                          DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8), 'F', E.NRINSJUREMPR)  AS NRINSC,
                          TO_CHAR(TO_DATE(:DTINICIAL),'YYYY-MM')  AS PERAPUR,
                          '1' AS TPINSCADQ,
                          REPLACE(REPLACE(REPLACE(EV.NRINSJURFILI,'.'),'/'),'-') AS NRINSCADQ,
                          DECODE(FO.IDTPIJURFORN,'J','1','F','2','') AS TPINSCPROD,
                          REPLACE(REPLACE(REPLACE(FO.NRINSJURFORN,'.'),'/'),'-') AS NRINSCPROD
                     FROM NOTAFISCAL NF, IMPOSTONF IP, PARAMEMPREINF P, ENVIOEVENTOREINF EV, EVENTOREINF ER, 
                          IMPOSTO IM, IMPOSTONFE IE, FORNECEDOR FO, EMPRESA E
                    WHERE IP.CDFILIAL     = NF.CDFILIAL
                      AND IP.NRLANCTONF   = NF.NRLANCTONF
                      AND NF.CDEMPRESA    = E.CDEMPRESA
                      AND NF.IDORIGDESTNF = 'F'
                      AND NF.CDEMPRESA    = :CDEMPRESA
                      and NF.CDFORNECED   = FO.CDFORNECED
                      AND ((IP.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (IP.NRSEQMAPOIMP = :NRSEQUMAPAPU))
                      AND IE.CDIMPOSTONFE = IM.CDIMPOSTONFE
                      AND IP.CDIMPOSTO    = IM.CDIMPOSTO
                      AND IE.CDIMPOSTONFE = '26'
                      AND P.CDEMPRESA(+)  = E.CDEMPRESA
                      AND EV.NRENVIO      = :NRENVIO
                      AND EV.CDESTABREINF = NF.CDFORNECED
                      AND EV.NREVENTO     = ER.NREVENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosConsulta2060($cdempresa, $dtinicial, $dtfinal) {
        $params = array( 
            'CDEMPRESA'     => $cdempresa,
            'DTINICIAL'     => $dtinicial,
            'DTFINAL'       => $dtfinal,
        );
        
        // Consulta para montar dados para consulta do envio do evento R2010
                
        $sql = "SELECT
                     TO_CHAR(TO_DATE(:DTINICIAL),'YYYY-MM') AS PERAPUR,
                     DECODE(IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                     DECODE(IDTPIJUREMPR,'J',SUBSTR(NRINSJUREMPR,1,8),'F',NRINSJUREMPR) AS NRINSC,
                     '1' AS TPINSCESTAB,
                     NRINSJUREMPR    AS NRINSCESTAB
                 FROM
                     (
                         SELECT
                             SUM(VRTOTABRUT) AS VRTOTABRUT,
                             SUM(VRENCARGO) AS VRENCARGO,
                             IDTPIJUREMPR,
                             NRINSJUREMPR
                         FROM
                             (
                                 SELECT
                                     SUM(NVL(VRNOTAFISC,0) ) AS VRTOTABRUT,
                                     SUM( (
                                         SELECT
                                             NVL(SUM(VRITEMENCA),0)
                                         FROM
                                             ENCARGO E,ITEMENCARGO ITE
                                         WHERE
                                             ITE.CDENCARGO = E.CDENCARGO
                                             AND N.CDFILIAL = ITE.CDFILIAL
                                             AND N.NRLANCTONF = ITE.NRLANCTONF
                                             AND E.IDENCARGO = 'A'
                                     ) ) AS VRENCARGO,
                                     E.IDTPIJUREMPR,
                                     E.NRINSJUREMPR
                                 FROM
                                     NOTAFISCAL N,
                                     IMPOSTONF I,
                                     IMPOSTO IM,
                                     EMPRESA E,
                                     ENDECLIE EC
                                 WHERE
                                     N.IDENTRSAIDOP = 'S'
                                     AND N.IDSTATUS IN (
                                         'E',
                                         'A',
                                         'C'
                                     )
                                     AND ( N.IDSISTEMA NOT IN (
                                         'REC',
                                         'FIS'
                                     )
                                           OR N.IDSISTEMA IS NULL )
                                     AND N.DTEMISSAO BETWEEN :DTINICIAL AND :DTFINAL
                                     AND N.CDEMPRESA = :CDEMPRESA
                                     AND N.CDFILIAL = I.CDFILIAL
                                     AND N.NRLANCTONF = I.NRLANCTONF
                                     AND I.NRSEQUMAPAPU IS NOT NULL
                                     AND I.CDIMPOSTO = IM.CDIMPOSTO
                                     AND IM.CDIMPOSTONFE = '50'
                                     AND E.CDEMPRESA = N.CDEMPRESA
                                     AND N.CDCLIENTE = EC.CDCLIENTE
                                     AND EC.CDPAIS = '0055'
                                     AND EC.IDTPENDECLIE = 'P'
                                 GROUP BY
                                     E.IDTPIJUREMPR,
                                     E.NRINSJUREMPR
                                 UNION ALL
                                 SELECT
                                     0 AS VRTOTABRUT,
                                     0 AS VRENCARGO,
                                     E.IDTPIJUREMPR,
                                     E.NRINSJUREMPR
                                 FROM
                                     EMPRESA E
                                 WHERE
                                     E.CDEMPRESA = :CDEMPRESA
                             )
                         GROUP BY
                             IDTPIJUREMPR,
                             NRINSJUREMPR
                     )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosConsulta2098($cdempresa, $dtmescompetenc) {
        $params = array( 
            'CDEMPRESA'         => $cdempresa,
            'DTMESCOMPETENC'    => $dtmescompetenc
        );
        
        // Consulta para montar dados para consulta do envio do evento R2010
                
        $sql = "SELECT
                 TO_CHAR(TO_DATE(:DTMESCOMPETENC),'YYYY-MM') AS PERAPUR,
                 DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                 DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8),'F',E.NRINSJUREMPR) AS NRINSC
             FROM
                 EMPRESA E
             WHERE
                 E.CDEMPRESA = :CDEMPRESA";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function insereHistenvio($params) {
        $sql = "INSERT INTO HISTENVIO
            (NRSEQHISTENVIO,
             NRENVIO,
             NRLANCTONF,
             CDFILIAL,
             IDOPERACAO,
             NRORG,
             NRORGINCLUSAO,
             CDOPERINCLUSAO) VALUES
            (:NRSEQHISTENVIO,
             :NRENVIO,
             :NRLANCTONF,
             :CDFILIAL,
             :IDOPERACAO,
             :NRORG,
             :NRORGINCLUSAO,
             :CDOPERINCLUSAO)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function notas2010Ou2020($params) {
        $sql = "SELECT NF.CDFILIAL,
                  NF.NRLANCTONF
                FROM NOTAFISCAL NF,
                  IMPOSTONF IP,
                  CLIENTE CL,
                  FORNECEDOR FO
                WHERE :CDPARTICIPANTE = CL.CDCLIENTE(+) 
                AND NF.CDCLIENTE      = CL.CDCLIENTE (+)
                AND :CDPARTICIPANTE   = FO.CDFORNECED(+)
                AND NF.CDFORNECED     = FO.CDFORNECED (+)
                AND NF.CDFILIAL       = IP.CDFILIAL
                AND NF.NRLANCTONF     = IP.NRLANCTONF
                AND IP.VRIMPOSTONF    > 0
                AND IP.CDFISCALNF     = '1'
                AND ((IP.NRSEQUMAPAPU = :NRSEQUMAPAPU)
                OR (IP.NRSEQMAPOIMP   = :NRSEQUMAPAPU))";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /************************
    *                       *
    *     Evento R1000      *
    *                       *
    ************************/
    public function getDadosR1000($cdempresa, $dtmescompetenc, $nrenvio, $idambiente, $dtfinal) {
        $params = array(
            "P_CDEMPRESA"  => $cdempresa,
            "P_DTINICIAL"  => $dtmescompetenc,
            "P_NRENVIO"    => $nrenvio,
            "P_IDAMBIENTE" => $idambiente,
            "P_DTFINAL"    => $dtfinal
        );
        
        // Consulta para produção
        $sql =  "SELECT 'ID'
                  ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                  ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                  ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                  ||LPAD(:P_NRENVIO,5,'0') id,
                  :P_IDAMBIENTE                                                                   AS TPAMB,
                  '1'                                                                             AS PROCEMI,
                  '1.5.1'                                                                         AS VERPROC,
                  DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')                                      AS TPINSC,
                  DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8), 'F', E.NRINSJUREMPR, ' ') AS NRINSC,
                  TO_CHAR(TO_DATE(:P_DTINICIAL),'YYYY-MM')                                        AS INIVALID,
                  TO_CHAR(TO_DATE(:P_DTFINAL),'YYYY-MM')                                          AS FIMVALID,
                  TO_CHAR(TO_DATE(P.DTINIVALIDADE),'YYYY-MM')                                     AS NEWINIVALID,
                  TO_CHAR(TO_DATE(P.DTFINVALIDADE),'YYYY-MM')                                     AS NEWFIMVALID,
                  C.CDESOCIAL                                                                     AS CLASSTRIB,
                  P.IDESCRITURECD                                                                 AS INDESCRITURACAO,
                  P.IDDESONERACAO                                                                 AS INDDESONERACAO,
                  P.IDACORDISENMULTA                                                              AS INDACORDOISENMULTA,
                  P.IDSITUPJ                                                                      AS INDSITPJ,
                  R.NMREPRES                                                                      AS NMCTT,
                  R.NRCPFREPRES                                                                   AS CPFCTT,
                  TRIM(REPLACE(REPLACE(REPLACE(REPLACE(R.NRDDDTELEREPRES1
                  ||R.NRTELEREPRES1 , '-'),'('),')'),' '))AS FONEFIXO,
                  ''                                      AS FONECEL,
                  R.DSEMAILREPRES                         AS EMAIL,
                  '26269316000177'                        AS CNPJSOFTHOUSE,
                  'Teknisa Software Ltda.'                AS NMRAZAO,
                  'Wilson Lima de Paula'                  AS NMCONT,
                  '3121222300'                            AS TELEFONE,
                  'contabilidade@teknisa.com'             AS EMAIL,
                  'S'                                     AS IDEEFR,
                  ''                                      AS CNPJEFR
                FROM PARAMEMPREINF P,
                  EMPRESA E,
                  REPRESLEGAL R,
                  CLASSTRIBUT C
                WHERE E.CDEMPRESA   = P.CDEMPRESA
                AND E.CDEMPRESA     = :P_CDEMPRESA
                AND P.CDREPRES      = R.CDREPRES
                AND P.NRCLASSTRIBUT = C.NRCLASSTRIBUT";
                
        // Consulta para montar dados usando certificado da Teknisa Software                
        // $sql =  "SELECT 'ID'
        //           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
        //           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
        //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
        //           ||LPAD(:P_NRENVIO,5,'0') id,
        //           :P_IDAMBIENTE                                                                       AS TPAMB,
        //           '1'                                                                                 AS PROCEMI,
        //           '1.5.1'                                                                             AS VERPROC,
        //           DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')                                          AS TPINSC,
        //           DECODE(E.IDTPIJUREMPR,'J',SUBSTR('26269316000177',1,8), 'F', '26269316000177', ' ') AS NRINSC,
        //           TO_CHAR(TO_DATE(:P_DTINICIAL),'YYYY-MM')                                            AS INIVALID,
        //           TO_CHAR(TO_DATE(:P_DTFINAL),'YYYY-MM')                                              AS FIMVALID,
        //           TO_CHAR(TO_DATE(P.DTINIVALIDADE),'YYYY-MM')                                         AS NEWINIVALID,
        //           TO_CHAR(TO_DATE(P.DTFINVALIDADE),'YYYY-MM')                                         AS NEWFIMVALID,
        //           C.CDESOCIAL                                                                         AS CLASSTRIB,
        //           P.IDESCRITURECD                                                                     AS INDESCRITURACAO,
        //           P.IDDESONERACAO                                                                     AS INDDESONERACAO,
        //           P.IDACORDISENMULTA                                                                  AS INDACORDOISENMULTA,
        //           P.IDSITUPJ                                                                          AS INDSITPJ,
        //           R.NMREPRES                                                                          AS NMCTT,
        //           R.NRCPFREPRES                                                                       AS CPFCTT,
        //           TRIM(REPLACE(REPLACE(REPLACE(REPLACE(R.NRDDDTELEREPRES1
        //           ||R.NRTELEREPRES1 , '-'),'('),')'),' '))                                            AS FONEFIXO,
        //           ''                                                                                  AS FONECEL,
        //           R.DSEMAILREPRES                                                                     AS EMAIL,
        //           '26269316000177'                                                                    AS CNPJSOFTHOUSE,
        //           'Teknisa Software Ltda.'                                                            AS NMRAZAO,
        //           'Wilson Lima de Paula'                                                              AS NMCONT,
        //           '3121222300'                                                                        AS TELEFONE,
        //           'contabilidade@teknisa.com'                                                         AS EMAIL,
        //           'S'                                                                                 AS IDEEFR,
        //           ''                                                                                  AS CNPJEFR
        //         FROM PARAMEMPREINF P,
        //           EMPRESA E,
        //           REPRESLEGAL R,
        //           CLASSTRIBUT C
        //         WHERE E.CDEMPRESA   = P.CDEMPRESA
        //         AND E.CDEMPRESA     = :P_CDEMPRESA
        //         AND P.CDREPRES      = R.CDREPRES
        //         AND P.NRCLASSTRIBUT = C.NRCLASSTRIBUT";
        
        // Consulta para limpar base de produção restrita usando certificado da Teknisa Software
        // $sql =  "SELECT 'ID'
        //           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
        //           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
        //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
        //           ||LPAD(:P_NRENVIO,5,'0') id,
        //           :P_IDAMBIENTE                                                                       AS TPAMB,
        //           '1'                                                                                 AS PROCEMI,
        //           '1.5.1'                                                                             AS VERPROC,
        //           DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')                                          AS TPINSC,
        //           DECODE(E.IDTPIJUREMPR,'J',SUBSTR('26269316000177',1,8), 'F', '26269316000177', ' ') AS NRINSC,
        //           TO_CHAR(TO_DATE(:P_DTINICIAL),'YYYY-MM')                                            AS INIVALID,
        //           TO_CHAR(TO_DATE(:P_DTFINAL),'YYYY-MM')                                              AS FIMVALID,
        //           TO_CHAR(TO_DATE(P.DTINIVALIDADE),'YYYY-MM')                                         AS NEWINIVALID,
        //           TO_CHAR(TO_DATE(P.DTFINVALIDADE),'YYYY-MM')                                         AS NEWFIMVALID,
        //           '00'                                                                                AS CLASSTRIB,
        //           P.IDESCRITURECD                                                                     AS INDESCRITURACAO,
        //           P.IDDESONERACAO                                                                     AS INDDESONERACAO,
        //           P.IDACORDISENMULTA                                                                  AS INDACORDOISENMULTA,
        //           P.IDSITUPJ                                                                          AS INDSITPJ,
        //           R.NMREPRES                                                                          AS NMCTT,
        //           R.NRCPFREPRES                                                                       AS CPFCTT,
        //           TRIM(REPLACE(REPLACE(REPLACE(REPLACE(R.NRDDDTELEREPRES1
        //           ||R.NRTELEREPRES1 , '-'),'('),')'),' '))                                            AS FONEFIXO,
        //           ''                                                                                  AS FONECEL,
        //           R.DSEMAILREPRES                                                                     AS EMAIL,
        //           '26269316000177'                                                                    AS CNPJSOFTHOUSE,
        //           'Teknisa Software Ltda.'                                                            AS NMRAZAO,
        //           'Wilson Lima de Paula'                                                              AS NMCONT,
        //           '3121222300'                                                                        AS TELEFONE,
        //           'contabilidade@teknisa.com'                                                         AS EMAIL,
        //           'S'                                                                                 AS IDEEFR,
        //           ''                                                                                  AS CNPJEFR
        //         FROM PARAMEMPREINF P,
        //           EMPRESA E,
        //           REPRESLEGAL R,
        //           CLASSTRIBUT C
        //         WHERE E.CDEMPRESA   = P.CDEMPRESA
        //         AND E.CDEMPRESA     = :P_CDEMPRESA
        //         AND P.CDREPRES      = R.CDREPRES
        //         AND P.NRCLASSTRIBUT = C.NRCLASSTRIBUT";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosR1000softHouse() {
        $sql =  "SELECT '26269316000177' cnpjSofthouse, 'Teknisa Software Ltda.' nmRazao, 'Wilson Lima de Paula' nmCont, '3121222300' telefone, 'contabilidade@teknisa.com' email
                FROM DUAL";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getDadosR1000LimparBase($cdempresa) {
        $params = array(
            "P_CDEMPRESA"  => $cdempresa
        );
        
        // Consulta para produção
        $sql =  "SELECT
                    IDTPIJUREMPR,
                    NRINSJUREMPR,
                    P.CDEMPRESA,
                    'ID' || DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||
                    RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||
                    TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') || '00000' AS ID,
                    P.IDAMBIENTE AS TPAMB,
                    '1' AS PROCEMI,
                    'RemoverContribuinte' AS VERPROC,
                    DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                    DECODE(E.IDTPIJUREMPR,'J',SUBSTR(E.NRINSJUREMPR,1,8), 'F', E.NRINSJUREMPR, ' ') AS NRINSC,
                    TO_CHAR(SYSDATE,'YYYY-MM') AS INIVALID,
                    '' AS FIMVALID,
                    '' AS NEWINIVALID,
                    '' AS NEWFIMVALID,
                    '00' AS CLASSTRIB,
                    P.IDESCRITURECD AS INDESCRITURACAO,
                    P.IDDESONERACAO AS INDDESONERACAO,
                    P.IDACORDISENMULTA AS INDACORDOISENMULTA,
                    P.IDSITUPJ AS INDSITPJ,
                    R.NMREPRES AS NMCTT,
                    R.NRCPFREPRES AS CPFCTT,
                    TRIM(REPLACE(REPLACE(REPLACE(REPLACE(R.NRDDDTELEREPRES1||R.NRTELEREPRES1 , '-'),'('),')'),' '))AS FONEFIXO,
                    '' AS FONECEL,
                    R.DSEMAILREPRES AS EMAIL,
                    '26269316000177' AS CNPJSOFTHOUSE,
                    'Teknisa Software Ltda.' AS NMRAZAO,
                    'Wilson Lima de Paula' AS NMCONT,
                    '3121222300' AS TELEFONE,
                    'contabilidade@teknisa.com' AS EMAIL,
                    'S' AS IDEEFR,
                    '' AS CNPJEFR
                    FROM PARAMEMPREINF P, EMPRESA E, REPRESLEGAL R
                    WHERE E.CDEMPRESA = P.CDEMPRESA
                    AND E.CDEMPRESA = :P_CDEMPRESA
                    AND P.CDREPRES = R.CDREPRES";
                
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    
    /************************
    *                       *
    *     Evento R1070      *
    *                       *
    ************************/
    public function getDadosR1070($cdempresa,$nrenvio, $nrevento, $versao, $idambiente, $cdprocesso) {
        
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();

        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R1070');
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $cdempresa, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO', Param::PARAM_INPUT, $nrenvio, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',   Param::PARAM_INPUT, $nrevento,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO',   Param::PARAM_INPUT, $versao,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',   Param::PARAM_INPUT, $idambiente,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPROCESSO',  Param::PARAM_INPUT, $cdprocesso,  Param::PARAM_TYPE_STR));
        
        $procedure->execute();
        $this->entityManager->flush();
        
        switch ($versao) {
            case '1.1':
                return false;
                //$sql =  "SELECT 'ID' ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') ||LPAD(:P_NRENVIO,5,'0') id, CDCAMPO1 AS TMPAMB, CDCAMPO2 AS PROCEMI , CDCAMPO3 AS VERPROC, CDCAMPO4 AS TPINSC, CDCAMPO5 AS NRINSC, CDCAMPO6 AS TPPROC, CDCAMPO8 AS NRPROC, TO_CHAR(DTCAMPO1,'YYYY-MM') AS INIVALID, TO_CHAR(DTCAMPO2,'YYYY-MM') AS FIMVALID, CDCAMPO9 AS INDAUTORIA, CDCAMPO10 AS UFVARA, CDCAMPO11 AS CODMUNIC, CDCAMPO12 AS IDVARA FROM ARQEFD_REINF A, EMPRESA E WHERE A.NREVENTO = :P_NREVENTO AND A.CDEMPRESA = :P_CDEMPRESA AND A.NRENVIO = :P_NRENVIO AND E.CDEMPRESA = :P_CDEMPRESA AND A.CDCAMPO7 = :P_CDPROCESSO";
                break;
            case '1.3':
            case '1.4':
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                    AS TMPAMB,
                          CDCAMPO2                    AS PROCEMI ,
                          CDCAMPO3                    AS VERPROC,
                          CDCAMPO4                    AS TPINSC,
                          DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR) AS NRINSC,
                          CDCAMPO6                    AS TPPROC,
                          CDCAMPO8                    AS NRPROC,
                          TO_CHAR(DTCAMPO1,'YYYY-MM') AS INIVALID,
                          TO_CHAR(DTCAMPO2,'YYYY-MM') AS FIMVALID,
                          CDCAMPO9                    AS INDAUTORIA,
                          CDCAMPO10                   AS UFVARA,
                          CDCAMPO11                   AS CODMUNIC,
                          CDCAMPO12                   AS IDVARA
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA
                        AND A.CDCAMPO7   = :P_CDPROCESSO";
                    /* $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                    AS TMPAMB,
                          CDCAMPO2                    AS PROCEMI ,
                          CDCAMPO3                    AS VERPROC,
                          CDCAMPO4                    AS TPINSC,
                          DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                          CDCAMPO6                    AS TPPROC,
                          CDCAMPO8                    AS NRPROC,
                          TO_CHAR(DTCAMPO1,'YYYY-MM') AS INIVALID,
                          TO_CHAR(DTCAMPO2,'YYYY-MM') AS FIMVALID,
                          CDCAMPO9                    AS INDAUTORIA,
                          CDCAMPO10                   AS UFVARA,
                          CDCAMPO11                   AS CODMUNIC,
                          CDCAMPO12                   AS IDVARA
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA
                        AND A.CDCAMPO7   = :P_CDPROCESSO"; */
                break;
                
                 case '1.05.01':
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                    AS TMPAMB,
                          CDCAMPO2                    AS PROCEMI ,
                          CDCAMPO3                    AS VERPROC,
                          CDCAMPO4                    AS TPINSC,
                          DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR) AS NRINSC,
                          CDCAMPO6                    AS TPPROC,
                          CDCAMPO8                    AS NRPROC,
                          TO_CHAR(DTCAMPO1,'YYYY-MM') AS INIVALID,
                          TO_CHAR(DTCAMPO2,'YYYY-MM') AS FIMVALID,
                          CDCAMPO9                    AS INDAUTORIA,
                          CDCAMPO10                   AS UFVARA,
                          CDCAMPO11                   AS CODMUNIC,
                          CDCAMPO12                   AS IDVARA
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA
                        AND A.CDCAMPO7   = :P_CDPROCESSO";
                    /* $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                    AS TMPAMB,
                          CDCAMPO2                    AS PROCEMI ,
                          CDCAMPO3                    AS VERPROC,
                          CDCAMPO4                    AS TPINSC,
                          DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                          CDCAMPO6                    AS TPPROC,
                          CDCAMPO8                    AS NRPROC,
                          TO_CHAR(DTCAMPO1,'YYYY-MM') AS INIVALID,
                          TO_CHAR(DTCAMPO2,'YYYY-MM') AS FIMVALID,
                          CDCAMPO9                    AS INDAUTORIA,
                          CDCAMPO10                   AS UFVARA,
                          CDCAMPO11                   AS CODMUNIC,
                          CDCAMPO12                   AS IDVARA
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA
                        AND A.CDCAMPO7   = :P_CDPROCESSO"; */
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio,
            "P_CDPROCESSO"   => $cdprocesso
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosR1070infoSusp($cdempresa, $nrevento, $nrenvio, $cdprocesso) {
        $params = array(
            "P_CDEMPRESA"   => $cdempresa,
            "P_NREVENTO"    => $nrevento,
            "P_NRENVIO"     => $nrenvio,
            'P_CDPROCESSO'=> $cdprocesso
        );
        $sql =  "SELECT CDCAMPO2 AS CODSUSP, TO_CHAR(DTCAMPO1,'YYYY-MM-DD') AS DTDECISAO, CDCAMPO3 AS INDSUSP, CDCAMPO4 AS INDDEPOSITO
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA = :P_CDEMPRESA
                        AND A.NRENVIO = :P_NRENVIO
                        AND CDCAMPO5 = :P_CDPROCESSO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
  
    
    /************************
    *                       *
    *     Evento R2010      *
    *                       *
    ************************/
    public function getDadosR2010($cdempresa, $dtinicial, $dtfinal, $nrenvio, $indcprb, $versao, $nrevento, $nrrecibo, $indretif, $cdestabreinf, $idambiente) {
        
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R2010');
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $cdempresa, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $dtinicial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL',   Param::PARAM_INPUT, $dtfinal,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO',   Param::PARAM_INPUT, $nrenvio,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',  Param::PARAM_INPUT, $nrevento,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INDCPRB',   Param::PARAM_INPUT, $indcprb,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO',    Param::PARAM_INPUT, $versao,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRRECIBO',  Param::PARAM_INPUT, $nrrecibo,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INDRETIF',  Param::PARAM_INPUT, $indretif,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',  Param::PARAM_INPUT, $idambiente,  Param::PARAM_TYPE_STR));
        
        $procedure->execute();
        $this->entityManager->flush();
      
        switch ($versao) {
            case '1.1':
                return false;
                //$sql =  "SELECT 'ID' ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') ||LPAD(:P_NRENVIO,5,'0') id, CDCAMPO1 AS INDRETIF, CDCAMPO2 AS NRRECIBO, CDCAMPO3 AS PERAPUR, CDCAMPO4 AS TMPAMB, CDCAMPO5 AS PROCEMI, CDCAMPO6 AS VERPROC, CDCAMPO7 AS TPINSC, DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(CDCAMPO8,1,8), CDCAMPO8) AS NRINSC, CDCAMPO9 AS TPINSCESTAB, CDCAMPO10 AS NRINSCESTAB, CDCAMPO11 AS INDOBRA, CDCAMPO12 AS CNPJPRESTADOR, trim(REPLACE(TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRTOTALBRUTO, trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRTOTALBASERET, trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRTOTALRETPRINC, trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRTOTALRETADIC, trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',',')) AS VLRTOTALNRETPRINC, trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',',')) AS VLRTOTALNRETADIC, CDCAMPO14 AS INDCPRB FROM ARQEFD_REINF A, EMPRESA E WHERE A.NREVENTO = :P_NREVENTO AND A.CDEMPRESA = :P_CDEMPRESA AND A.NRENVIO = :P_NRENVIO AND E.CDEMPRESA = :P_CDEMPRESA AND A.CDCAMPO15 = :P_CDESTABREINF";
                break;
            case '1.3':
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                           ||LPAD(:P_NRENVIO,5,'0') id,
                           CDCAMPO1                                                                    AS INDRETIF,
                           CDCAMPO2                                                                    AS NRRECIBO,
                           CDCAMPO3                                                                    AS PERAPUR,
                           CDCAMPO4                                                                    AS TMPAMB,
                           CDCAMPO5                                                                    AS PROCEMI,
                           CDCAMPO6                                                                    AS VERPROC,
                           CDCAMPO7                                                                    AS TPINSC,
                           DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(CDCAMPO8,1,8), CDCAMPO8)                 AS NRINSC,
                           CDCAMPO9                                                                    AS TPINSCESTAB,
                           CDCAMPO10                                                                   AS NRINSCESTAB,
                           CDCAMPO11                                                                   AS INDOBRA,
                           CDCAMPO12                                                                   AS CNPJPRESTADOR,
                           trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))                 AS VLRTOTALBRUTO,
                           trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',','))                 AS VLRTOTALBASERET,
                           trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',','))                 AS VLRTOTALRETPRINC,
                           trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',','))                 AS VLRTOTALRETADIC,
                           trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',','))                 AS VLRTOTALNRETPRINC,
                           trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',','))                 AS VLRTOTALNRETADIC,
                           CDCAMPO14                                                                   AS INDCPRB
                         FROM ARQEFD_REINF A,
                           EMPRESA E
                         WHERE A.NREVENTO = :P_NREVENTO
                         AND A.CDEMPRESA  = :P_CDEMPRESA
                         AND A.NRENVIO    = :P_NRENVIO
                         AND E.CDEMPRESA  = :P_CDEMPRESA
                         AND A.CDCAMPO15  = :P_CDESTABREINF";
                break;
            case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                           ||LPAD(:P_NRENVIO,5,'0') id,
                           CDCAMPO1                                                                    AS INDRETIF,
                           CDCAMPO2                                                                    AS NRRECIBO,
                           CDCAMPO3                                                                    AS PERAPUR,
                           CDCAMPO4                                                                    AS TMPAMB,
                           CDCAMPO5                                                                    AS PROCEMI,
                           CDCAMPO6                                                                    AS VERPROC,
                           CDCAMPO7                                                                    AS TPINSC,
                           DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(CDCAMPO8,1,8), CDCAMPO8)                 AS NRINSC,
                           CDCAMPO9                                                                    AS TPINSCESTAB,
                           CDCAMPO10                                                                   AS NRINSCESTAB,
                           CDCAMPO11                                                                   AS INDOBRA,
                           CDCAMPO12                                                                   AS CNPJPRESTADOR,
                           trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))                 AS VLRTOTALBRUTO,
                           trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',','))                 AS VLRTOTALBASERET,
                           trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',','))                 AS VLRTOTALRETPRINC,
                           trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',','))                 AS VLRTOTALRETADIC,
                           trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',','))                 AS VLRTOTALNRETPRINC,
                           trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',','))                 AS VLRTOTALNRETADIC,
                           CDCAMPO14                                                                   AS INDCPRB
                         FROM ARQEFD_REINF A,
                           EMPRESA E
                         WHERE A.NREVENTO = :P_NREVENTO
                         AND A.CDEMPRESA  = :P_CDEMPRESA
                         AND A.NRENVIO    = :P_NRENVIO
                         AND E.CDEMPRESA  = :P_CDEMPRESA
                         AND A.CDCAMPO15  = :P_CDESTABREINF";
                         
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //               ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //               ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //               ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //               ||LPAD(:P_NRENVIO,5,'0') id,
                //               CDCAMPO1                                                                    AS INDRETIF,
                //               CDCAMPO2                                                                    AS NRRECIBO,
                //               CDCAMPO3                                                                    AS PERAPUR,
                //               CDCAMPO4                                                                    AS TMPAMB,
                //               CDCAMPO5                                                                    AS PROCEMI,
                //               CDCAMPO6                                                                    AS VERPROC,
                //               CDCAMPO7                                                                    AS TPINSC,
                //               DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                //               CDCAMPO9                                                                    AS TPINSCESTAB,
                //               '26269316000177'                                                            AS NRINSCESTAB,
                //               CDCAMPO11                                                                   AS INDOBRA,
                //               CDCAMPO12                                                                   AS CNPJPRESTADOR,
                //               trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))                 AS VLRTOTALBRUTO,
                //               trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',','))                 AS VLRTOTALBASERET,
                //               trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',','))                 AS VLRTOTALRETPRINC,
                //               trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',','))                 AS VLRTOTALRETADIC,
                //               trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',','))                 AS VLRTOTALNRETPRINC,
                //               trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',','))                 AS VLRTOTALNRETADIC,
                //               CDCAMPO14                                                                   AS INDCPRB
                //             FROM ARQEFD_REINF A,
                //               EMPRESA E
                //             WHERE A.NREVENTO = :P_NREVENTO
                //             AND A.CDEMPRESA  = :P_CDEMPRESA
                //             AND A.NRENVIO    = :P_NRENVIO
                //             AND E.CDEMPRESA  = :P_CDEMPRESA
                //             AND A.CDCAMPO15  = :P_CDESTABREINF";
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio,
            "P_CDESTABREINF" => $cdestabreinf
        );
    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosR2010nfs($cdempresa, $nrevento, $nrenvio, $cdestabreinf) {
        $params = array(
            "P_CDEMPRESA"   => $cdempresa,
            "P_NREVENTO"    => $nrevento,
            "P_NRENVIO"     => $nrenvio,
            'P_CDESTABREINF'=> $cdestabreinf,
        );
        $sql =  "SELECT CDCAMPO5                                              AS SERIE,
                  CDCAMPO6                                                   AS NUMDOCTO,
                  TO_CHAR(DTCAMPO1,'YYYY-MM-DD')                             AS DTEMISSAONF,
                  TRIM(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))AS VLRBRUTO,
                  CDCAMPO7                                                   AS OBS,
                  CDCAMPO9 AS CDFILIAL,
                  CDCAMPO10 AS NRLANCTONF
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                AND A.CDEMPRESA  = :P_CDEMPRESA
                AND A.NRENVIO    = :P_NRENVIO
                AND CDCAMPO8     = :P_CDESTABREINF";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosR2010infoTpServ($cdempresa, $nrevento, $nrenvio, $nrlanctonf, $cdfilial) {
        $params = array(
            "P_NREVENTO"  => $nrevento,
            "P_CDEMPRESA" => $cdempresa,
            "P_NRENVIO"   => $nrenvio,
            "P_NRLANCTONF" => $nrlanctonf,
            "P_CDFILIAL"   => $cdfilial
        );
        $sql =  "SELECT CDCAMPO5                                                       AS TPSERVICO,
                  (TRIM((REPLACE(TO_CHAR(SUM(VRCAMPO1),'999999999990.00'),'.',',') ))) AS VLRBASERET,
                  (TRIM(REPLACE(TO_CHAR(SUM(VRCAMPO2),'999999999990.00'),'.',',')))    AS VLRRETENCAO,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO3),'999999999990.00'),'.',',')))   AS VLRRETSUB,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO4),'999999999990.00'),'.',',')))   AS VLRNRETPRINC,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO5),'999999999990.00'),'.',',')))   AS VLRSERVICOS15,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO6),'999999999990.00'),'.',',')))   AS VLRSERVICOS20,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO7),'999999999990.00'),'.',',')))   AS VLRSERVICOS25,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO8),'999999999990.00'),'.',',')))   AS VLRADICIONAL,
                  (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO9),'999999999990.00'),'.',',')))   AS VLRNRETADIC
                FROM ARQEFD_REINF A,
                  CLASERVMOBEMPR CL
                WHERE A.NREVENTO = :P_NREVENTO
                AND A.CDEMPRESA  = :P_CDEMPRESA
                AND A.NRENVIO    = :P_NRENVIO
                AND A.CDCAMPO5   = CL.CDCLASERVMOBEMP
                AND A.CDCAMPO6   = :P_CDFILIAL
                AND A.CDCAMPO7   = :P_NRLANCTONF
                GROUP BY CDCAMPO5";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function todasNotas_eventoR2010($params) {
        $sql = "SELECT NF.NRORG,
                      NF.CDSERIEENTR AS SERIE,
                      NF.NRNOTAFISC  AS NUMDOCTO,
                      NF.DTEMISSAO   AS DTEMISSAONF,
                      NF.VRNOTAFISC  AS VLRBRUTO,
                      ''             AS OBS,
                      NF.CDFILIAL,
                      NF.CDFORNECED,
                      NF.NRLANCTONF,
                      NF.CDINSCMUNI,
                      IP.CDIMPOSTO,
                      NF.CDEMPRESA
                    FROM NOTAFISCAL NF,
                      IMPOSTONF IP, MAPAAPURAC MP,
                      ITEMPROIMPOS IT
                    WHERE NF.CDFORNECED = :CDPARTICIPANTE
                    AND NF.CDFILIAL     = IP.CDFILIAL
                    AND NF.NRLANCTONF   = IP.NRLANCTONF
                    AND IT.CDFILIAL        = IP.CDFILIAL
                    AND IT.NRLANCTONF      = IP.NRLANCTONF
                    AND MP.CDIMPOSTO    = :CDIMPOSTO
                    AND IP.VRIMPOSTONF  > 0
                    AND IT.CDFISCALIT      = '1'
                    AND MP.CDEMPRESA    = :CDEMPRESA
                    AND MP.DTINIPERIODO = :DTINICIAL
                    AND MP.DTFIMPERIODO = :DTFINAL
                    AND ((IP.NRSEQUMAPAPU = MP.NRSEQUMAPAPU) or (IP.NRSEQMAPOIMP = MP.NRSEQUMAPAPU))";
        
        
        // Select alterado para pegar apenas notas fiscais com CDFISCALIT = 1, que é o unico considerado para a transmissão do reinf
        /*"SELECT NF.NRORG,
                  NF.CDSERIEENTR AS SERIE,
                  NF.NRNOTAFISC  AS NUMDOCTO,
                  NF.DTEMISSAO   AS DTEMISSAONF,
                  NF.VRNOTAFISC  AS VLRBRUTO,
                  ''             AS OBS,
                  NF.CDFILIAL,
                  NF.NRLANCTONF,
                  NF.CDINSCMUNI,
                  IP.CDIMPOSTO,
                  NF.CDEMPRESA
                FROM NOTAFISCAL NF,
                  IMPOSTONF IP, MAPAAPURAC MP
                WHERE NF.CDFORNECED = :CDPARTICIPANTE
                AND NF.CDFILIAL     = IP.CDFILIAL
                AND NF.NRLANCTONF   = IP.NRLANCTONF
                AND MP.CDIMPOSTO    = :CDIMPOSTO
                AND IP.VRIMPOSTONF  > 0
                AND MP.CDEMPRESA    = :CDEMPRESA
                AND MP.DTINIPERIODO = :DTINICIAL
                AND MP.DTFIMPERIODO = :DTFINAL
                AND ((IP.NRSEQUMAPAPU = MP.NRSEQUMAPAPU) or (IP.NRSEQMAPOIMP = MP.NRSEQUMAPAPU))";*/
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /*
    public function getDadosR2010infoProcRetPr($cdempresa, $nrevento, $nrenvio) {
        $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_NREVENTO"  => $nrevento,
            "P_NRENVIO"   => $nrenvio,
        );
        $sql =  "SELECT CDCAMPO22  AS TPPROCRETPRINC,
                         CDCAMPO23 AS NRPROCRETPRINC,
                         CDCAMPO24 AS CODSUSPPRINC,
                         TRIM(  REPLACE (TO_CHAR(VRCAMPO21,'999999999990.00'),'.',',') )AS VALORPRINC
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA = :P_CDEMPRESA
                        AND A.NRENVIO = :P_NRENVIO
                        AND CDCAMPO22 IS NOT NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosR2010infoProcRetAd($cdempresa, $nrevento, $nrenvio) {
        $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_NREVENTO"  => $nrevento,
            "P_NRENVIO"   => $nrenvio,
        );
        $sql =  "SELECT CDCAMPO26                 AS TPPROCRETADIC,
                      CDCAMPO27                   AS NRPROCRETADIC,
                      CDCAMPO28                   AS CODSUSPADIC,
                      TRIM(  REPLACE (TO_CHAR(VRCAMPO22,'999999999990.00'),'.',',') )AS VALORADIC
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA = :P_CDEMPRESA
                        AND A.NRENVIO = :P_NRENVIO
                        AND CDCAMPO26 IS NOT NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    */
   
    /************************
    *                       *
    *     Evento R2020      *
    *                       *
    ************************/
    public function getDadosR2020($cdempresa, $dtinicial, $dtfinal, $nrenvio, $indcprb, $versao, $nrevento, $nrrecibo, $indretif, $cdestabreinf, $idambiente) {
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();

        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R2020');
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $cdempresa, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $dtinicial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL',   Param::PARAM_INPUT, $dtfinal,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO',   Param::PARAM_INPUT, $nrenvio,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',  Param::PARAM_INPUT, $nrevento,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INDCPRB',   Param::PARAM_INPUT, $indcprb,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO',    Param::PARAM_INPUT, $versao,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRRECIBO',  Param::PARAM_INPUT, $nrrecibo,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INDRETIF',  Param::PARAM_INPUT, $indretif,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',  Param::PARAM_INPUT, $idambiente,  Param::PARAM_TYPE_STR));
        
        $procedure->execute();
        $this->entityManager->flush();

        switch ($versao) {
            case '1.1':
                return false;
                //$sql =  "SELECT 'ID' ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') ||LPAD(:P_NRENVIO,5,'0') id, CDCAMPO1 AS INDRETIF, CDCAMPO2 AS NRRECIBO, CDCAMPO3 AS PERAPUR, CDCAMPO4 AS TMPAMB, CDCAMPO5 AS PROCEMI, CDCAMPO6 AS VERPROC, CDCAMPO7 AS TPINSC, DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(CDCAMPO8,1,8), CDCAMPO8) AS NRINSC, CDCAMPO9 AS TPINSCESTABPREST, CDCAMPO10 AS NRINSCESTABPREST, CDCAMPO11 AS TPINSCTOMADOR, CDCAMPO12 AS NRINSCTOMADOR, CDCAMPO13 AS INDOBRA, trim(REPLACE(TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRTOTALBRUTO, trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRTOTALBASERET, trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRTOTALRETPRINC, trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRTOTALRETADIC, trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',',')) AS VLRTOTALNRETPRINC, trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',',')) AS VLRTOTALNRETADIC, CDCAMPO14 AS INDCPRB FROM ARQEFD_REINF A, EMPRESA E WHERE A.NREVENTO = :P_NREVENTO AND A.CDEMPRESA = :P_CDEMPRESA AND A.NRENVIO = :P_NRENVIO AND E.CDEMPRESA = :P_CDEMPRESA AND A.CDCAMPO15 = :P_CDESTABREINF";
                break;
            case '1.3':
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                    AS INDRETIF,
                          CDCAMPO2                                                    AS NRRECIBO,
                          CDCAMPO3                                                    AS PERAPUR,
                          CDCAMPO4                                                    AS TMPAMB,
                          CDCAMPO5                                                    AS PROCEMI,
                          CDCAMPO6                                                    AS VERPROC,
                          CDCAMPO7                                                    AS TPINSC,
                          DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR) AS NRINSC,
                          CDCAMPO9                                                    AS TPINSCESTABPREST,
                          CDCAMPO10                                                   AS NRINSCESTABPREST,
                          CDCAMPO11                                                   AS TPINSCTOMADOR,
                          CDCAMPO12                                                   AS NRINSCTOMADOR,
                          CDCAMPO13                                                   AS INDOBRA,
                          trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRTOTALBRUTO,
                          trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRTOTALBASERET,
                          trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRTOTALRETPRINC,
                          trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRTOTALRETADIC,
                          trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',',')) AS VLRTOTALNRETPRINC,
                          trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',',')) AS VLRTOTALNRETADIC,
                          CDCAMPO14                                                   AS INDCPRB
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO   
                        AND E.CDEMPRESA  = :P_CDEMPRESA
                        AND A.CDCAMPO15  = :P_CDESTABREINF";
                
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //       ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //       ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //       ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //       ||LPAD(:P_NRENVIO,5,'0') id,
                //       CDCAMPO1                                                    AS INDRETIF,
                //       CDCAMPO2                                                    AS NRRECIBO,
                //       CDCAMPO3                                                    AS PERAPUR,
                //       CDCAMPO4                                                    AS TMPAMB,
                //       CDCAMPO5                                                    AS PROCEMI,
                //       CDCAMPO6                                                    AS VERPROC,
                //       CDCAMPO7                                                    AS TPINSC,
                //       DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                //       CDCAMPO9                                                    AS TPINSCESTABPREST,
                //       '26269316000177'                                            AS NRINSCESTABPREST,
                //       CDCAMPO11                                                   AS TPINSCTOMADOR,
                //       CDCAMPO12                                                   AS NRINSCTOMADOR,
                //       CDCAMPO13                                                   AS INDOBRA,
                //       trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRTOTALBRUTO,
                //       trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRTOTALBASERET,
                //       trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRTOTALRETPRINC,
                //       trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRTOTALRETADIC,
                //       trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',',')) AS VLRTOTALNRETPRINC,
                //       trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',',')) AS VLRTOTALNRETADIC,
                //       CDCAMPO14                                                   AS INDCPRB
                //     FROM ARQEFD_REINF A,
                //       EMPRESA E
                //     WHERE A.NREVENTO = :P_NREVENTO
                //     AND A.CDEMPRESA  = :P_CDEMPRESA
                //     AND A.NRENVIO    = :P_NRENVIO   
                //     AND E.CDEMPRESA  = :P_CDEMPRESA
                //     AND A.CDCAMPO15  = :P_CDESTABREINF"; 
                break;
                 case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                    AS INDRETIF,
                          CDCAMPO2                                                    AS NRRECIBO,
                          CDCAMPO3                                                    AS PERAPUR,
                          CDCAMPO4                                                    AS TMPAMB,
                          CDCAMPO5                                                    AS PROCEMI,
                          CDCAMPO6                                                    AS VERPROC,
                          CDCAMPO7                                                    AS TPINSC,
                          DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR) AS NRINSC,
                          CDCAMPO9                                                    AS TPINSCESTABPREST,
                          CDCAMPO10                                                   AS NRINSCESTABPREST,
                          CDCAMPO11                                                   AS TPINSCTOMADOR,
                          CDCAMPO12                                                   AS NRINSCTOMADOR,
                          CDCAMPO13                                                   AS INDOBRA,
                          trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRTOTALBRUTO,
                          trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRTOTALBASERET,
                          trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRTOTALRETPRINC,
                          trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRTOTALRETADIC,
                          trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',',')) AS VLRTOTALNRETPRINC,
                          trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',',')) AS VLRTOTALNRETADIC,
                          CDCAMPO14                                                   AS INDCPRB
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO   
                        AND E.CDEMPRESA  = :P_CDEMPRESA
                        AND A.CDCAMPO15  = :P_CDESTABREINF";
                
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //       ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //       ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //       ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //       ||LPAD(:P_NRENVIO,5,'0') id,
                //       CDCAMPO1                                                    AS INDRETIF,
                //       CDCAMPO2                                                    AS NRRECIBO,
                //       CDCAMPO3                                                    AS PERAPUR,
                //       CDCAMPO4                                                    AS TMPAMB,
                //       CDCAMPO5                                                    AS PROCEMI,
                //       CDCAMPO6                                                    AS VERPROC,
                //       CDCAMPO7                                                    AS TPINSC,
                //       DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                //       CDCAMPO9                                                    AS TPINSCESTABPREST,
                //       '26269316000177'                                            AS NRINSCESTABPREST,
                //       CDCAMPO11                                                   AS TPINSCTOMADOR,
                //       CDCAMPO12                                                   AS NRINSCTOMADOR,
                //       CDCAMPO13                                                   AS INDOBRA,
                //       trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRTOTALBRUTO,
                //       trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRTOTALBASERET,
                //       trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRTOTALRETPRINC,
                //       trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRTOTALRETADIC,
                //       trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',',')) AS VLRTOTALNRETPRINC,
                //       trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',',')) AS VLRTOTALNRETADIC,
                //       CDCAMPO14                                                   AS INDCPRB
                //     FROM ARQEFD_REINF A,
                //       EMPRESA E
                //     WHERE A.NREVENTO = :P_NREVENTO
                //     AND A.CDEMPRESA  = :P_CDEMPRESA
                //     AND A.NRENVIO    = :P_NRENVIO   
                //     AND E.CDEMPRESA  = :P_CDEMPRESA
                //     AND A.CDCAMPO15  = :P_CDESTABREINF"; 
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio,
            "P_CDESTABREINF" => $cdestabreinf
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosR2020nfs($cdempresa, $nrevento, $nrenvio, $cdestabreinf) {
        $params = array(
            "P_CDEMPRESA"   => $cdempresa,
            "P_NREVENTO"    => $nrevento,
            "P_NRENVIO"     => $nrenvio,
            'P_CDESTABREINF'=> $cdestabreinf,
        );
        $sql =  "SELECT CDCAMPO5 AS SERIE,
                    CDCAMPO6 AS NUMDOCTO,
                    TO_CHAR(DTCAMPO1,'YYYY-MM-DD') AS DTEMISSAONF,
                    TRIM(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))AS VLRBRUTO,
                    CDCAMPO7 AS OBS,
                    CDCAMPO9 AS CDFILIAL,
                    CDCAMPO10 AS NRLANCTONF
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO    = :P_NREVENTO
                    AND A.CDEMPRESA = :P_CDEMPRESA
                    AND A.NRENVIO   = :P_NRENVIO
                    AND CDCAMPO8    = :P_CDESTABREINF";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosR2020infoTpServ($cdempresa, $nrevento, $nrenvio, $nrlanctonf, $cdfilial) {
        $params = array(
            "P_NREVENTO"  => $nrevento,
            "P_CDEMPRESA" => $cdempresa,
            "P_NRENVIO"   => $nrenvio,
            "P_NRLANCTONF" => $nrlanctonf,
            "P_CDFILIAL" => $cdfilial
        );
        $sql =  "SELECT CDCAMPO5 AS TPSERVICO,
                    (TRIM((REPLACE(TO_CHAR(SUM(VRCAMPO1),'999999999990.00'),'.',',') ))) AS VLRBASERET, (TRIM(REPLACE(TO_CHAR(SUM(VRCAMPO2),'999999999990.00'),'.',','))) AS VLRRETENCAO, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO3),'999999999990.00'),'.',','))) AS VLRRETSUB, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO4),'999999999990.00'),'.',','))) AS VLRNRETPRINC, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO5),'999999999990.00'),'.',','))) AS VLRSERVICOS15, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO6),'999999999990.00'),'.',','))) AS VLRSERVICOS20, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO7),'999999999990.00'),'.',','))) AS VLRSERVICOS25, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO8),'999999999990.00'),'.',','))) AS VLRADICIONAL, (TRIM( REPLACE(TO_CHAR(SUM(VRCAMPO9),'999999999990.00'),'.',','))) AS VLRNRETADIC
                FROM ARQEFD_REINF A, CLASERVMOBEMPR CL
                WHERE A.NREVENTO = :P_NREVENTO
                    AND A.CDEMPRESA = :P_CDEMPRESA
                    AND A.NRENVIO = :P_NRENVIO
                    AND A.CDCAMPO5 = CL.CDCLASERVMOBEMP
                    AND A.CDCAMPO6   = :P_CDFILIAL
                    AND A.CDCAMPO7   = :P_NRLANCTONF
                GROUP BY  CDCAMPO5";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function todasNotas_eventoR2020($params) {
        $sql = /*"SELECT NVL(NF.CDSERIE,'0') AS SERIE,
                  NF.NRNOTAFISC            AS NUMDOCTO,
                  NF.DTEMISSAO             AS DTEMISSAONF,
                  NF.VRNOTAFISC            AS VLRBRUTO,
                  ''                       AS OBS,
                  NF.CDFILIAL,
                  NF.NRLANCTONF,
                  NF.CDINSCMUNI,
                  IP.CDIMPOSTO,
                  NF.NRORG,
                  NF.CDEMPRESA
                FROM NOTAFISCAL NF,
                  IMPOSTONF IP,
                  MAPAAPURAC MP,
                  ITEMPROIMPOS IT
                WHERE NF.CDCLIENTE  = :CDPARTICIPANTE
                AND NF.CDFILIAL     = IP.CDFILIAL
                AND NF.NRLANCTONF   = IP.NRLANCTONF
                AND IT.CDFILIAL        = IP.CDFILIAL
                AND IT.NRLANCTONF      = IP.NRLANCTONF
                AND MP.CDIMPOSTO  = :CDIMPOSTO
                AND IP.VRIMPOSTONF > 0
                AND IT.CDFISCALIT      = '1'
                AND MP.CDEMPRESA    = :CDEMPRESA
                AND MP.DTINIPERIODO = :DTINICIAL
                AND MP.DTFIMPERIODO = :DTFINAL
                AND ((IP.NRSEQUMAPAPU = MP.NRSEQUMAPAPU) or (IP.NRSEQMAPOIMP = MP.NRSEQUMAPAPU))";*/
        
        // Select alterado para pegar apenas notas fiscais com CDFISCALIT = 1, que é o unico considerado para a transmissão do reinf
        "SELECT NVL(NF.CDSERIE,'0') AS SERIE,
                  NF.NRNOTAFISC            AS NUMDOCTO,
                  NF.DTEMISSAO             AS DTEMISSAONF,
                  NF.VRNOTAFISC            AS VLRBRUTO,
                  ''                       AS OBS,
                  NF.CDFILIAL,
                  NF.NRLANCTONF,
                  NF.CDINSCMUNI,
                  IP.CDIMPOSTO,
                  NF.NRORG,
                  NF.CDEMPRESA
                FROM NOTAFISCAL NF,
                  IMPOSTONF IP,
                  MAPAAPURAC MP
                WHERE NF.CDCLIENTE  = :CDPARTICIPANTE
                AND NF.CDFILIAL     = IP.CDFILIAL
                AND NF.NRLANCTONF   = IP.NRLANCTONF
                AND IP.VRIMPOSTONF > 0
                AND MP.CDIMPOSTO  = :CDIMPOSTO
                AND MP.CDEMPRESA    = :CDEMPRESA
                AND MP.DTINIPERIODO = :DTINICIAL
                AND MP.DTFIMPERIODO = :DTFINAL
                AND ((IP.NRSEQUMAPAPU = MP.NRSEQUMAPAPU) or (IP.NRSEQMAPOIMP = MP.NRSEQUMAPAPU))";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params); 
        return $std->fetchAll();
    }
    
    /*
    public function getDadosR2020infoProcRetPr($cdempresa, $nrevento, $nrenvio) {
        $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_NREVENTO"  => $nrevento,
            "P_NRENVIO"   => $nrenvio,
        );
        $sql =  "SELECT CDCAMPO22  AS TPPROCRETPRINC,
                         CDCAMPO23 AS NRPROCRETPRINC,
                         CDCAMPO24 AS CODSUSPPRINC,
                         TRIM(  REPLACE (TO_CHAR(VRCAMPO21,'999999999990.00'),'.',',') )AS VALORPRINC
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA = :P_CDEMPRESA
                        AND A.NRENVIO = :P_NRENVIO
                        AND CDCAMPO22 IS NOT NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosR2020infoProcRetAd($cdempresa, $nrevento, $nrenvio) {
        $params = array(
            "P_CDEMPRESA" => $cdempresa,
            "P_NREVENTO"  => $nrevento,
            "P_NRENVIO"   => $nrenvio,
        );
        $sql =  "SELECT CDCAMPO26                 AS TPPROCRETADIC,
                      CDCAMPO27                   AS NRPROCRETADIC,
                      CDCAMPO28                   AS CODSUSPADIC,
                      TRIM(  REPLACE (TO_CHAR(VRCAMPO22,'999999999990.00'),'.',',') )AS VALORADIC
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA = :P_CDEMPRESA
                        AND A.NRENVIO = :P_NRENVIO
                        AND CDCAMPO26 IS NOT NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    */

     public function getDadosR2055($cdempresa, $dtinicial, $dtfinal, $nrenvio, $versao, $nrevento, $nrrecibo, $indretif, $cdestabreinf, $idambiente) {
       // var_dump($cdempresa);die;
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R2055');
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $cdempresa, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $dtinicial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL',   Param::PARAM_INPUT, $dtfinal,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO',   Param::PARAM_INPUT, $nrenvio,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',  Param::PARAM_INPUT, $nrevento,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO',    Param::PARAM_INPUT, $versao,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRRECIBO',  Param::PARAM_INPUT, $nrrecibo,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INDRETIF',  Param::PARAM_INPUT, $indretif,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',  Param::PARAM_INPUT, $idambiente,  Param::PARAM_TYPE_STR));
     
        $procedure->execute();
        $this->entityManager->flush();
      
        switch ($versao) {
            case '1.1':
                return false;
                break;
            case '1.3':
                 return false;
                 break;
            case '1.4':
                 return false;
                break;
            case '1.05.01':
                // Consulta para produção
                $sql ="SELECT 'ID'
                        ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                        ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                        ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                        ||LPAD(:P_NRENVIO,5,'0') id,
                           CDCAMPO1 AS INDRETIF,
                           CDCAMPO2 AS NRRECIBO,
                           CDCAMPO3 AS PERAPUR,
                           CDCAMPO4 AS TMPAMB,
                           CDCAMPO5 AS PROCEMI,
                           CDCAMPO6 AS VERPROC,
                           CDCAMPO7 AS TPINSC,
                           CDCAMPO8 AS NRINSC,
                           CDCAMPO9 AS TPINSCADQ,
                           CDCAMPO10 AS NRINSCADQ,
                           CDCAMPO11 AS TPINSCPROD,
                           CDCAMPO12 AS NRINSCPROD,
                           CDCAMPO13 AS INDOPCCP
                      FROM ARQEFD_REINF A, EMPRESA E
                     WHERE A.NREVENTO  = :P_NREVENTO
                       AND A.CDEMPRESA = :P_CDEMPRESA
                       AND A.NRENVIO   = :P_NRENVIO
                       AND E.CDEMPRESA = :P_CDEMPRESA
                       AND A.CDCAMPO15 = :P_CDESTABREINF";
                     
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio,
            "P_CDESTABREINF" => $cdestabreinf
        );
    //    var_dump($params);die;
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetch();
    }
    
      public function getDadosR2055detAquis($cdempresa, $nrevento, $nrenvio, $cdestabreinf) {
        $params = array(
            "P_CDEMPRESA"   => $cdempresa,
            "P_NREVENTO"    => $nrevento,
            "P_NRENVIO"     => $nrenvio,
            'P_CDESTABREINF'=> $cdestabreinf,
        );
        $sql =  "SELECT 
                    CDCAMPO14 AS INDAQUIS,
                    TRIM(REPLACE(TO_CHAR(VRCAMPO1,'999999999990.00'),'.',',')) AS VLRBRUTO,
                    TRIM(REPLACE(TO_CHAR(VRCAMPO2,'999999999990.00'),'.',',')) AS VLRCPDESCPR,
                    TRIM(REPLACE(TO_CHAR(VRCAMPO3,'999999999990.00'),'.',',')) AS VLRRATDESCPR,
                    TRIM(REPLACE(TO_CHAR(VRCAMPO4,'999999999990.00'),'.',',')) AS VLRSENARDESC
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO = :P_NREVENTO
                AND A.CDEMPRESA  = :P_CDEMPRESA
                AND A.NRENVIO    = :P_NRENVIO
                AND A.CDCAMPO15     = :P_CDESTABREINF";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /************************
    *                       *
    *     Evento R2060      *
    *                       *
    ************************/
    public function getDadosR2060($cdempresa, $dtinicial, $dtfinal, $nrenvio, $nrevento, $nrrecibo, $dsversao, $indretif, $idambiente, $cdatividade, $vraliquota) {
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();
            
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R2060');
        $procedure->addParam(new Param('P_CDEMPRESA',       Param::PARAM_INPUT, $cdempresa,      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL',       Param::PARAM_INPUT, $dtinicial,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL',         Param::PARAM_INPUT, $dtfinal,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO',         Param::PARAM_INPUT, $nrenvio,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',        Param::PARAM_INPUT, $nrevento,       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRRECIBO',        Param::PARAM_INPUT, $nrrecibo,       Param::PARAM_TYPE_STR));
        //$procedure->addParam(new Param('P_DSVERSAO',      Param::PARAM_INPUT, $dsversao,       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INDRETIF',        Param::PARAM_INPUT, $indretif,     Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',      Param::PARAM_INPUT, $idambiente,     Param::PARAM_TYPE_STR));
        if(isset($cdatividade)){
            $procedure->addParam(new Param('P_CDATIVIDADE',     Param::PARAM_INPUT, $cdatividade,     Param::PARAM_TYPE_STR));
        }
        if(isset($vraliquota)){
            $procedure->addParam(new Param('P_VRALIQUOTA',      Param::PARAM_INPUT, $vraliquota,     Param::PARAM_TYPE_STR));
        }
        //$procedure->addParam(new Param('P_DTMESCOMPETENC', Param::PARAM_INPUT, $dtmescompetenc, Param::PARAM_TYPE_STR));
        
        $procedure->execute();
        $this->entityManager->flush();
        
        switch ($dsversao) {
            case '1.1':
                return false;
                //$sql =  "SELECT 'ID' ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') ||LPAD(:P_NRENVIO,5,'0') id, CDCAMPO1 AS PERAPUR, CDCAMPO2 AS TMPAMB, CDCAMPO3 AS PROCEMI, CDCAMPO4 AS VERPROC, CDCAMPO5 AS TPINSC, CDCAMPO8 AS NRINSC, CDCAMPO7 AS NMRESP, CDCAMPO8 AS CPFRESP, TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO, CDCAMPO10 AS EMAIL, CDCAMPO11 AS EVTSERVTM, CDCAMPO12 AS EVTSERVPR, CDCAMPO13 AS EVTASSDESPREC, CDCAMPO14 AS EVTASSDESPREP, CDCAMPO15 AS EVTCOMPROD, CDCAMPO16 AS EVTCPRB, CDCAMPO17 AS EVTPGTOS, CDCAMPO18 AS COMPSEMMOVTO FROM ARQEFD_REINF A, EMPRESA E WHERE A.NREVENTO = :P_NREVENTO AND A.CDEMPRESA = :P_CDEMPRESA AND A.NRENVIO = :P_NRENVIO AND E.CDEMPRESA = :P_CDEMPRESA ";
                break;
            case '1.3':
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                         ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                         ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                         ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                         ||LPAD(:P_NRENVIO,5,'0') id,
                         CDCAMPO1                                                            AS INDRETIF, 
                         CDCAMPO2                                                            AS NRRECIBO,
                         CDCAMPO3                                                            AS PERAPUR, 
                         CDCAMPO4                                                            AS TPAMB, 
                         CDCAMPO5                                                            AS PROCEMI, 
                         CDCAMPO6                                                            AS VERPROC,
                        
                         CDCAMPO7                                                            AS TPINSC,
                         CDCAMPO8                                                            AS NRINSC,
                         trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))         AS VLRRECBRUTATOTAL,
                         trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',','))         AS VLRCPAPURTOTAL, 
                         trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',','))         AS VLRCPRBSUSPTOTAL, 
                        
                         CDCAMPO9                                                            AS TPINSCESTAB, 
                         CDCAMPO10                                                           AS NRINSCESTAB
                        
                         
                        FROM ARQEFD_REINF A,
                        EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
                        
                break;
                case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                         ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                         ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                         ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                         ||LPAD(:P_NRENVIO,5,'0') id,
                         CDCAMPO1                                                            AS INDRETIF, 
                         CDCAMPO2                                                            AS NRRECIBO,
                         CDCAMPO3                                                            AS PERAPUR, 
                         CDCAMPO4                                                            AS TPAMB, 
                         CDCAMPO5                                                            AS PROCEMI, 
                         CDCAMPO6                                                            AS VERPROC,
                        
                         CDCAMPO7                                                            AS TPINSC,
                         CDCAMPO8                                                            AS NRINSC,
                         trim(REPLACE (TO_CHAR(VRCAMPO1,'999999999990.00'),'.',','))         AS VLRRECBRUTATOTAL,
                         trim(REPLACE (TO_CHAR(VRCAMPO2,'999999999990.00'),'.',','))         AS VLRCPAPURTOTAL, 
                         trim(REPLACE (TO_CHAR(VRCAMPO3,'999999999990.00'),'.',','))         AS VLRCPRBSUSPTOTAL, 
                        
                         CDCAMPO9                                                            AS TPINSCESTAB, 
                         CDCAMPO10                                                           AS NRINSCESTAB
                        
                         
                        FROM ARQEFD_REINF A,
                        EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
                        
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDadosR2060tipoCod($cdempresa, $nrevento, $nrenvio, $nrinscestab) {
        $params = array(
            "P_CDEMPRESA"   => $cdempresa,
            "P_NREVENTO"    => $nrevento,
            "P_NRENVIO"     => $nrenvio,
            'P_NRINSCESTAB'=> $nrinscestab,
        );
        
        $sql =  "SELECT  CDCAMPO11                                                           AS CODATIVECON,
                         trim(REPLACE (TO_CHAR(VRCAMPO4,'999999999990.00'),'.',','))         AS VLRRECBRUTAATIV, 
                         trim(REPLACE (TO_CHAR(VRCAMPO5,'999999999990.00'),'.',','))         AS VLREXCRECBRUTA, 
                         trim(REPLACE (TO_CHAR(VRCAMPO6,'999999999990.00'),'.',','))         AS VLRADICRECBRUTA,
                         trim(REPLACE (TO_CHAR(VRCAMPO7,'999999999990.00'),'.',','))         AS VLRBCCPRB, 
                         trim(REPLACE (TO_CHAR(VRCAMPO8,'999999999990.00'),'.',','))         AS VLRCPRBAPUR

                FROM ARQEFD_REINF A
                WHERE A.NREVENTO        = :P_NREVENTO
                    AND A.CDEMPRESA     = :P_CDEMPRESA
                    AND A.NRENVIO       = :P_NRENVIO
                    AND CDCAMPO10       = :P_NRINSCESTAB";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosR2060tipoAjuste($cdempresa, $nrevento, $nrenvio, $codativecon) {
        $params = array(
            "P_CDEMPRESA"   => $cdempresa,
            "P_NREVENTO"    => $nrevento,
            "P_NRENVIO"     => $nrenvio,
            "P_CODATIVECON" => $codativecon
        );
        $sql =  "SELECT  CDCAMPO12                                                           AS TPAJUSTE,
                         CDCAMPO13                                                           AS CODAJUSTE,
                         CDCAMPO14                                                           AS DESCAJUSTE,
                         trim(REPLACE (TO_CHAR(VRCAMPO9,'999999999990.00'),'.',','))         AS VLRAJUSTE, 
                         CDCAMPO15                                                           AS DTAJUSTE
        
                FROM ARQEFD_REINF A
                WHERE A.NREVENTO        = :P_NREVENTO
                    AND A.CDEMPRESA     = :P_CDEMPRESA
                    AND A.NRENVIO       = :P_NRENVIO
                    AND CDCAMPO11       = :P_CODATIVECON";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /************************
    *                       *
    *     Evento R2098      *
    *                       *
    ************************/
    public function getDadosR2098($cdempresa, $nrenvio, $nrevento, $dsversao, $idambiente, $dtmescompetenc) {
 
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();

        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R2098');
        $procedure->addParam(new Param('P_CDEMPRESA',      Param::PARAM_INPUT, $cdempresa,      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO',        Param::PARAM_INPUT, $nrenvio,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',       Param::PARAM_INPUT, $nrevento,       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DSVERSAO',       Param::PARAM_INPUT, $dsversao,       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',     Param::PARAM_INPUT, $idambiente,     Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTMESCOMPETENC', Param::PARAM_INPUT, $dtmescompetenc, Param::PARAM_TYPE_STR));
        
        $procedure->execute();
        $this->entityManager->flush();
        
        switch ($dsversao) {
            case '1.1':
                return false;
                //$sql =  "SELECT 'ID' ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') ||LPAD(:P_NRENVIO,5,'0') id, CDCAMPO1 AS PERAPUR, CDCAMPO2 AS TMPAMB, CDCAMPO3 AS PROCEMI, CDCAMPO4 AS VERPROC, CDCAMPO5 AS TPINSC, CDCAMPO8 AS NRINSC, CDCAMPO7 AS NMRESP, CDCAMPO8 AS CPFRESP, TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO, CDCAMPO10 AS EMAIL, CDCAMPO11 AS EVTSERVTM, CDCAMPO12 AS EVTSERVPR, CDCAMPO13 AS EVTASSDESPREC, CDCAMPO14 AS EVTASSDESPREP, CDCAMPO15 AS EVTCOMPROD, CDCAMPO16 AS EVTCPRB, CDCAMPO17 AS EVTPGTOS, CDCAMPO18 AS COMPSEMMOVTO FROM ARQEFD_REINF A, EMPRESA E WHERE A.NREVENTO = :P_NREVENTO AND A.CDEMPRESA = :P_CDEMPRESA AND A.NRENVIO = :P_NRENVIO AND E.CDEMPRESA = :P_CDEMPRESA ";
                break;
            case '1.3':
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                            AS PERAPUR,
                          CDCAMPO2                                                            AS TMPAMB,
                          CDCAMPO3                                                            AS PROCEMI,
                          CDCAMPO4                                                            AS VERPROC,
                          CDCAMPO5                                                            AS TPINSC,
                          CDCAMPO6                                                            AS NRINSC
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
                        
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') id,
                //           CDCAMPO1                                                            AS PERAPUR,
                //           CDCAMPO2                                                            AS TMPAMB,
                //           CDCAMPO3                                                            AS PROCEMI,
                //           CDCAMPO4                                                            AS VERPROC,
                //           CDCAMPO5                                                            AS TPINSC,
                //           SUBSTR('26269316000177',1,8)                                        AS NRINSC
                //         FROM ARQEFD_REINF A,
                //           EMPRESA E
                //         WHERE A.NREVENTO = :P_NREVENTO
                //         AND A.CDEMPRESA  = :P_CDEMPRESA
                //         AND A.NRENVIO    = :P_NRENVIO
                //         AND E.CDEMPRESA  = :P_CDEMPRESA"; 
                break;
                case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                            AS PERAPUR,
                          CDCAMPO2                                                            AS TMPAMB,
                          CDCAMPO3                                                            AS PROCEMI,
                          CDCAMPO4                                                            AS VERPROC,
                          CDCAMPO5                                                            AS TPINSC,
                          CDCAMPO6                                                            AS NRINSC
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
                        
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') id,
                //           CDCAMPO1                                                            AS PERAPUR,
                //           CDCAMPO2                                                            AS TMPAMB,
                //           CDCAMPO3                                                            AS PROCEMI,
                //           CDCAMPO4                                                            AS VERPROC,
                //           CDCAMPO5                                                            AS TPINSC,
                //           SUBSTR('26269316000177',1,8)                                        AS NRINSC
                //         FROM ARQEFD_REINF A,
                //           EMPRESA E
                //         WHERE A.NREVENTO = :P_NREVENTO
                //         AND A.CDEMPRESA  = :P_CDEMPRESA
                //         AND A.NRENVIO    = :P_NRENVIO
                //         AND E.CDEMPRESA  = :P_CDEMPRESA"; 
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    /************************
    *                       *
    *     Evento R2099      *
    *                       *
    ************************/
    public function getDadosR2099($cdempresa, $nrenvio, $nrevento, $dsversao, $idambiente, $dtmescompetenc) {
        /* Verifica se ja exites os dados para o eventos no periodo informado.
        Caso exista apaga os dados para não ocorrer problemas na chamada da procedure*/
        $this->deleteDadosProcedureReinf($cdempresa, $nrevento, $nrenvio);
        $this->entityManager->flush();

        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'REINF_R2099');
        $procedure->addParam(new Param('P_CDEMPRESA',      Param::PARAM_INPUT, $cdempresa,      Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRENVIO',        Param::PARAM_INPUT, $nrenvio,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREVENTO',       Param::PARAM_INPUT, $nrevento,       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DSVERSAO',       Param::PARAM_INPUT, $dsversao,       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDAMBIENTE',     Param::PARAM_INPUT, $idambiente,     Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTMESCOMPETENC', Param::PARAM_INPUT, $dtmescompetenc, Param::PARAM_TYPE_STR));
        
        $procedure->execute();
        $this->entityManager->flush();
        
        switch ($dsversao) {
            case '1.1':
                return false;
                //$sql =  "SELECT 'ID' ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ') ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0') ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS') ||LPAD(:P_NRENVIO,5,'0') id, CDCAMPO1 AS PERAPUR, CDCAMPO2 AS TMPAMB, CDCAMPO3 AS PROCEMI, CDCAMPO4 AS VERPROC, CDCAMPO5 AS TPINSC, CDCAMPO8 AS NRINSC, CDCAMPO7 AS NMRESP, CDCAMPO8 AS CPFRESP, TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO, CDCAMPO10 AS EMAIL, CDCAMPO11 AS EVTSERVTM, CDCAMPO12 AS EVTSERVPR, CDCAMPO13 AS EVTASSDESPREC, CDCAMPO14 AS EVTASSDESPREP, CDCAMPO15 AS EVTCOMPROD, CDCAMPO16 AS EVTCPRB, CDCAMPO17 AS EVTPGTOS, CDCAMPO18 AS COMPSEMMOVTO FROM ARQEFD_REINF A, EMPRESA E WHERE A.NREVENTO = :P_NREVENTO AND A.CDEMPRESA = :P_CDEMPRESA AND A.NRENVIO = :P_NRENVIO AND E.CDEMPRESA = :P_CDEMPRESA ";
                break;
            case '1.3':
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                            AS PERAPUR,
                          CDCAMPO2                                                            AS TMPAMB,
                          CDCAMPO3                                                            AS PROCEMI,
                          CDCAMPO4                                                            AS VERPROC,
                          CDCAMPO5                                                            AS TPINSC,
                          CDCAMPO6                                                            AS NRINSC,
                          CDCAMPO7                                                            AS NMRESP,
                          CDCAMPO8                                                            AS CPFRESP,
                          TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO,
                          CDCAMPO10                                                           AS EMAIL,
                          CDCAMPO11                                                           AS EVTSERVTM,
                          CDCAMPO12                                                           AS EVTSERVPR,
                          NVL(CDCAMPO13,'N')                                                  AS EVTASSDESPREC,
                          NVL(CDCAMPO14,'N')                                                  AS EVTASSDESPREP,
                          CDCAMPO15                                                           AS EVTCOMPROD,
                          CDCAMPO16                                                           AS EVTCPRB,
                          CDCAMPO17                                                           AS EVTPGTOS,
                          CDCAMPO18                                                           AS COMPSEMMOVTO
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                            AS PERAPUR,
                          CDCAMPO2                                                            AS TMPAMB,
                          CDCAMPO3                                                            AS PROCEMI,
                          CDCAMPO4                                                            AS VERPROC,
                          CDCAMPO5                                                            AS TPINSC,
                          CDCAMPO6                                                            AS NRINSC,
                          CDCAMPO7                                                            AS NMRESP,
                          CDCAMPO8                                                            AS CPFRESP,
                          TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO,
                          CDCAMPO10                                                           AS EMAIL,
                          NVL(CDCAMPO11,'N')                                                  AS EVTSERVTM,
                          NVL(CDCAMPO12,'N')                                                  AS EVTSERVPR,
                          NVL(CDCAMPO13,'N')                                                  AS EVTASSDESPREC,
                          NVL(CDCAMPO14,'N')                                                  AS EVTASSDESPREP,
                          NVL(CDCAMPO15,'N')                                                  AS EVTCOMPROD,
                          NVL(CDCAMPO16,'N')                                                  AS EVTCPRB
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
                        
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') id,
                //           CDCAMPO1                                                            AS PERAPUR,
                //           CDCAMPO2                                                            AS TMPAMB,
                //           CDCAMPO3                                                            AS PROCEMI,
                //           CDCAMPO4                                                            AS VERPROC,
                //           CDCAMPO5                                                            AS TPINSC,
                //           SUBSTR('26269316000177',1,8)                                        AS NRINSC,
                //           CDCAMPO7                                                            AS NMRESP,
                //           CDCAMPO8                                                            AS CPFRESP,
                //           TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO,
                //           CDCAMPO10                                                           AS EMAIL,
                //           CDCAMPO11                                                           AS EVTSERVTM,
                //           CDCAMPO12                                                           AS EVTSERVPR,
                //           CDCAMPO13                                                           AS EVTASSDESPREC,
                //           CDCAMPO14                                                           AS EVTASSDESPREP,
                //           CDCAMPO15                                                           AS EVTCOMPROD,
                //           CDCAMPO16                                                           AS EVTCPRB,
                //           CDCAMPO17                                                           AS EVTPGTOS,
                //           CDCAMPO18                                                           AS COMPSEMMOVTO
                //         FROM ARQEFD_REINF A,
                //           EMPRESA E
                //         WHERE A.NREVENTO = :P_NREVENTO
                //         AND A.CDEMPRESA  = :P_CDEMPRESA
                //         AND A.NRENVIO    = :P_NRENVIO
                //         AND E.CDEMPRESA  = :P_CDEMPRESA";
                break;
                
                case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR(E.NRINSJUREMPR,1,8), E.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') id,
                          CDCAMPO1                                                            AS PERAPUR,
                          CDCAMPO2                                                            AS TMPAMB,
                          CDCAMPO3                                                            AS PROCEMI,
                          CDCAMPO4                                                            AS VERPROC,
                          CDCAMPO5                                                            AS TPINSC,
                          CDCAMPO6                                                            AS NRINSC,
                          CDCAMPO7                                                            AS NMRESP,
                          CDCAMPO8                                                            AS CPFRESP,
                          TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO,
                          CDCAMPO10                                                           AS EMAIL,
                          NVL(CDCAMPO11,'N')                                                  AS EVTSERVTM,
                          NVL(CDCAMPO12,'N')                                                  AS EVTSERVPR,
                          NVL(CDCAMPO13,'N')                                                  AS EVTASSDESPREC,
                          NVL(CDCAMPO14,'N')                                                  AS EVTASSDESPREP,
                          NVL(CDCAMPO15,'N')                                                  AS EVTCOMPROD,
                          NVL(CDCAMPO16,'N')                                                  AS EVTCPRB,
                          CDCAMPO19                                                           AS EVTAQUIS
                        FROM ARQEFD_REINF A,
                          EMPRESA E
                        WHERE A.NREVENTO = :P_NREVENTO
                        AND A.CDEMPRESA  = :P_CDEMPRESA
                        AND A.NRENVIO    = :P_NRENVIO
                        AND E.CDEMPRESA  = :P_CDEMPRESA";
                        
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(E.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(E.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') id,
                //           CDCAMPO1                                                            AS PERAPUR,
                //           CDCAMPO2                                                            AS TMPAMB,
                //           CDCAMPO3                                                            AS PROCEMI,
                //           CDCAMPO4                                                            AS VERPROC,
                //           CDCAMPO5                                                            AS TPINSC,
                //           SUBSTR('26269316000177',1,8)                                        AS NRINSC,
                //           CDCAMPO7                                                            AS NMRESP,
                //           CDCAMPO8                                                            AS CPFRESP,
                //           TRIM(REPLACE(REPLACE(REPLACE(REPLACE(CDCAMPO9, '-'),'('),')'),' ')) AS FONEFIXO,
                //           CDCAMPO10                                                           AS EMAIL,
                //           CDCAMPO11                                                           AS EVTSERVTM,
                //           CDCAMPO12                                                           AS EVTSERVPR,
                //           CDCAMPO13                                                           AS EVTASSDESPREC,
                //           CDCAMPO14                                                           AS EVTASSDESPREP,
                //           CDCAMPO15                                                           AS EVTCOMPROD,
                //           CDCAMPO16                                                           AS EVTCPRB,
                //           CDCAMPO17                                                           AS EVTPGTOS,
                //           CDCAMPO18                                                           AS COMPSEMMOVTO
                //         FROM ARQEFD_REINF A,
                //           EMPRESA E
                //         WHERE A.NREVENTO = :P_NREVENTO
                //         AND A.CDEMPRESA  = :P_CDEMPRESA
                //         AND A.NRENVIO    = :P_NRENVIO
                //         AND E.CDEMPRESA  = :P_CDEMPRESA";
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_CDEMPRESA"    => $cdempresa,
            "P_NREVENTO"     => $nrevento,
            "P_NRENVIO"      => $nrenvio
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    /************************
    *                       *
    *     Evento R5011      *
    *                       *
    ************************/
    public function getDadosR5011($nrenvio, $dsversao) {
        switch ($dsversao) {
            case '1.3':
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR(EMP.NRINSJUREMPR,1,8), EMP.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') ID,
                          TO_CHAR(ENV.DTMESCOMPETENC, 'YYYY-mm') AS PERAPUR,
                          DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                          DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR(EMP.NRINSJUREMPR,1,8), EMP.NRINSJUREMPR) AS NRINSC
                        FROM ENVIOEVENTOREINF ENV
                        JOIN EMPRESA EMP
                        ON EMP.CDEMPRESA = ENV.CDEMPRESA
                        WHERE NRENVIO = :P_NRENVIO";
                        
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') ID,
                //           TO_CHAR(ENV.DTMESCOMPETENC, 'YYYY-mm') AS PERAPUR,
                //           DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                //           DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), EMP.NRINSJUREMPR) AS NRINSC
                //         FROM ENVIOEVENTOREINF ENV
                //         JOIN EMPRESA EMP
                //         ON EMP.CDEMPRESA = ENV.CDEMPRESA
                //         WHERE NRENVIO = :P_NRENVIO";
                break;
                
                case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR(EMP.NRINSJUREMPR,1,8), EMP.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') ID,
                          TO_CHAR(ENV.DTMESCOMPETENC, 'YYYY-mm') AS PERAPUR,
                          DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                          DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR(EMP.NRINSJUREMPR,1,8), EMP.NRINSJUREMPR) AS NRINSC
                        FROM ENVIOEVENTOREINF ENV
                        JOIN EMPRESA EMP
                        ON EMP.CDEMPRESA = ENV.CDEMPRESA
                        WHERE NRENVIO = :P_NRENVIO";
                        
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') ID,
                //           TO_CHAR(ENV.DTMESCOMPETENC, 'YYYY-mm') AS PERAPUR,
                //           DECODE(EMP.IDTPIJUREMPR,'J','1','F','2',' ') AS TPINSC,
                //           DECODE(EMP.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), EMP.NRINSJUREMPR) AS NRINSC
                //         FROM ENVIOEVENTOREINF ENV
                //         JOIN EMPRESA EMP
                //         ON EMP.CDEMPRESA = ENV.CDEMPRESA
                //         WHERE NRENVIO = :P_NRENVIO";
                break;
            default:
                return false;
                break;
        }
        $params = array(
            'P_NRENVIO' => $nrenvio
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    /************************
    *                       *
    *     Evento R9000      *
    *                       *
    ************************/
    public function getDadosR9000($nrenvio, $nrenvioexclusao, $dsversao) {
        switch ($dsversao) {
            case '1.3':
            case '1.4':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(EM.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR(EM.NRINSJUREMPR,1,8), EM.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') AS ID,
                          DECODE(EM.IDTPIJUREMPR, 'J', 1, 2) AS TPINSC,
                          DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR(EM.NRINSJUREMPR,1,8), EM.NRINSJUREMPR) AS NRINSC,
                          EVENTO.NMEVENTO AS TPEVENTO,
                          ENVIO.NRRECIBO AS NRRECEVT,
                          DECODE(EVENTO.NMEVENTO, 'R-3010', TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM-DD'), TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM')) AS PERAPUR
                        FROM ENVIOEVENTOREINF ENVIO,
                          EVENTOREINF EVENTO,
                          EMPRESA EM
                        WHERE ENVIO.NRENVIO    = :P_NRENVIOEXCLUSAO 
                        AND EVENTO.NREVENTO = ENVIO.NREVENTO
                        AND EM.CDEMPRESA  = ENVIO.CDEMPRESA";
                
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(EM.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') AS ID,
                //           DECODE(EM.IDTPIJUREMPR, 'J', 1, 2) AS TPINSC,
                //           DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                //           EVENTO.NMEVENTO AS TPEVENTO,
                //           ENVIO.NRRECIBO AS NRRECEVT,
                //           DECODE(EVENTO.NMEVENTO, 'R-3010', TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM-DD'), TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM')) AS PERAPUR
                //         FROM ENVIOEVENTOREINF ENVIO,
                //           EVENTOREINF EVENTO,
                //           EMPRESA EM
                //         WHERE ENVIO.NRENVIO    = :P_NRENVIOEXCLUSAO 
                //         AND EVENTO.NREVENTO = ENVIO.NREVENTO
                //         AND EM.CDEMPRESA  = ENVIO.CDEMPRESA"; 
                break;
                
                case '1.05.01':
                // Consulta para produção
                $sql =  "SELECT 'ID'
                          ||DECODE(EM.IDTPIJUREMPR,'J','1','F','2',' ')
                          ||RPAD(DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR(EM.NRINSJUREMPR,1,8), EM.NRINSJUREMPR),14,'0')
                          ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                          ||LPAD(:P_NRENVIO,5,'0') AS ID,
                          DECODE(EM.IDTPIJUREMPR, 'J', 1, 2) AS TPINSC,
                          DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR(EM.NRINSJUREMPR,1,8), EM.NRINSJUREMPR) AS NRINSC,
                          EVENTO.NMEVENTO AS TPEVENTO,
                          ENVIO.NRRECIBO AS NRRECEVT,
                          DECODE(EVENTO.NMEVENTO, 'R-3010', TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM-DD'), TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM')) AS PERAPUR
                        FROM ENVIOEVENTOREINF ENVIO,
                          EVENTOREINF EVENTO,
                          EMPRESA EM
                        WHERE ENVIO.NRENVIO    = :P_NRENVIOEXCLUSAO 
                        AND EVENTO.NREVENTO = ENVIO.NREVENTO
                        AND EM.CDEMPRESA  = ENVIO.CDEMPRESA";
                
                // Consulta para montar dados usando certificado da Teknisa Software
                // $sql =  "SELECT 'ID'
                //           ||DECODE(EM.IDTPIJUREMPR,'J','1','F','2',' ')
                //           ||RPAD(DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177'),14,'0')
                //           ||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')
                //           ||LPAD(:P_NRENVIO,5,'0') AS ID,
                //           DECODE(EM.IDTPIJUREMPR, 'J', 1, 2) AS TPINSC,
                //           DECODE(EM.IDTPIJUREMPR, 'J', SUBSTR('26269316000177',1,8), '26269316000177') AS NRINSC,
                //           EVENTO.NMEVENTO AS TPEVENTO,
                //           ENVIO.NRRECIBO AS NRRECEVT,
                //           DECODE(EVENTO.NMEVENTO, 'R-3010', TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM-DD'), TO_CHAR(ENVIO.DTMESCOMPETENC, 'YYYY-MM')) AS PERAPUR
                //         FROM ENVIOEVENTOREINF ENVIO,
                //           EVENTOREINF EVENTO,
                //           EMPRESA EM
                //         WHERE ENVIO.NRENVIO    = :P_NRENVIOEXCLUSAO 
                //         AND EVENTO.NREVENTO = ENVIO.NREVENTO
                //         AND EM.CDEMPRESA  = ENVIO.CDEMPRESA"; 
                break;
            default:
                return false;
                break;
        }
        $params = array(
            "P_NRENVIO"      => $nrenvio,
            "P_NRENVIOEXCLUSAO"      => $nrenvioexclusao
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getInscricoesMunicipais($empresa) {
           
        $sql =  "SELECT CDINSCMUNI FROM INSCRMUNICIP WHERE CDEMPRESA = :P_CDEMPRESA";
                

        $params = array(
            "P_CDEMPRESA"      => $empresa
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getCDNATUJURI($nrorg, $empresa) {
           
        $sql =  "SELECT CDNATUJURI FROM EMPRESA WHERE CDEMPRESA =:P_CDEMPRESA AND NRORG =:P_NRORG";
                

        $params = array(
            "P_CDEMPRESA"  => $empresa,
            "P_NRORG"      => $nrorg
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getEventoR1000($versao) {
           
        $sql =  "SELECT * FROM EVENTOREINF WHERE NMEVENTO = 'R-1000' AND DSVERSAO = :P_DSVERSAO";
        
        $params = array(
            "P_DSVERSAO"  => $versao
        );
                
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function deletaEnvioEventoLimparBase($cdEmpresa, $idAmbiente){
        
        $sql =  "DELETE FROM ENVIOEVENTOREINF 
                        WHERE CDEMPRESA = :P_CDEMPRESA
                              AND IDAMBIENTE = :P_IDAMBIENTE";  
        
        $params = array(
            "P_CDEMPRESA"  => $cdEmpresa,
            "P_IDAMBIENTE"  => $idAmbiente
        );
                
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    
    public function getVrexportacao($dtinicial, $dtfinal, $cdEmpresa){
        
        $sql =  "SELECT NVL(SUM(N.VRNOTAFISC),0) AS V_VREXPORTACAO
                    FROM ENDECLIE E, NOTAFISCAL N
                        WHERE E.CDPAIS <> '0055'
                        AND E.IDTPENDECLIE = 'P'
                        AND E.CDCLIENTE = N.CDCLIENTE
                        AND (N.IDSISTEMA NOT IN ('REC','FIS') OR N.IDSISTEMA IS NULL)
                        AND N.DTEMISSAO BETWEEN :P_DTINICIAL AND :P_DTFINAL
                        AND N.CDEMPRESA = :P_CDEMPRESA
                        AND N.IDENTRSAIDOP = 'S'
                        AND N.IDSTATUS IN ('E','A')";  
        
        $params = array(
            "P_DTINICIAL"   => $dtinicial,
            "P_DTFINAL"     => $dtfinal,
            "P_CDEMPRESA"   => $cdEmpresa
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function getDetalhamentoR2060($vrexportacao, $dtinicial, $dtfinal, $cdEmpresa){
        
        $sql =  "SELECT RE.*,
                      E.NMRAZSOCEMPR ,
                      E.IDTPIJUREMPR
                      ||E.NRINSJUREMPR AS NRINSJUR
                    FROM
                      (SELECT TO_CHAR(TO_DATE(:P_DTINICIAL),'YYYY-MM')                       AS PERAPUR,
                        '1'                                                                  AS PROCEMI,
                        '1.5.1'                                                              AS VERPROC,
                        DECODE(IDTPIJUREMPR,'J','1','F','2',' ')                             AS TPINSC,
                        DECODE(IDTPIJUREMPR,'J',SUBSTR(NRINSJUREMPR,1,8), 'F', NRINSJUREMPR) AS NRINSC,
                        '1'                                                                  AS TPINSCESTAB,
                        NRINSJUREMPR                                                         AS NRINSCESTAB,
                        NVL(VRTOTABRUT,0)       + NVL(:V_VREXPORTACAO,0) - NVL(VRENCARGO,0)        AS VLRRECBRUTATOTAL,
                        ROUND((NVL(VRTOTABRUT,0)-NVL(VRENCARGO,0))*(4.5/100),2)                    AS VLRCPAPURTOTAL,
                        0                                                                          AS VLRCPRBSUSPTOTAL,
                        '00000025'                                                                 AS CODATIVECON,
                        NVL(VRTOTABRUT,0) - NVL(VRENCARGO,0) + NVL(:V_VREXPORTACAO,0)              AS VLRRECBRUTAATIV,
                        NVL(:V_VREXPORTACAO,0)                                                     AS VLREXCRECBRUTA,
                        0                                                                          AS VLRADICRECBRUTA,
                        NVL(VRTOTABRUT,0)       - NVL(VRENCARGO,0)                                       AS VLRBCCPRB,
                        ROUND((NVL(VRTOTABRUT,0)-NVL(VRENCARGO,0))*(4.5/100),2)                          AS VLRCPRBAPUR,
                        '0'                                                                              AS TPAJUSTE,
                        '11'                                                                             AS CODAJUSTE,
                        NVL(:V_VREXPORTACAO,0)                                                           AS VLRAJUSTE,
                        'Servicos no exterior'                                                           AS DESCAJUSTE ,
                        TO_CHAR(TO_DATE(:P_DTFINAL),'YYYY-MM')                                           AS DTAJUSTE
                      FROM
                        (SELECT SUM(NVL(VRNOTAFISC,0)) AS VRTOTABRUT,
                          SUM(
                          (SELECT NVL(SUM(VRITEMENCA),0)
                          FROM ENCARGO E,
                            ITEMENCARGO ITE
                          WHERE ITE.CDENCARGO = E.CDENCARGO
                          AND N.CDFILIAL      = ITE.CDFILIAL
                          AND N.NRLANCTONF    = ITE.NRLANCTONF
                          AND E.IDENCARGO     = 'A'
                          )) AS VRENCARGO,
                          E.IDTPIJUREMPR,
                          E.NRINSJUREMPR
                        FROM NOTAFISCAL N,
                          IMPOSTONF I,
                          IMPOSTO IM,
                          EMPRESA E,
                          ENDECLIE EC
                        WHERE N.IDENTRSAIDOP  = 'S'
                        AND N.IDSTATUS       IN ('E','A')
                        AND (N.IDSISTEMA NOT IN ('REC','FIS')
                        OR N.IDSISTEMA       IS NULL)
                        AND N.DTEMISSAO BETWEEN :P_DTINICIAL AND :P_DTFINAL
                        AND N.CDEMPRESA     = :P_CDEMPRESA
                        AND N.CDFILIAL      = I.CDFILIAL
                        AND N.NRLANCTONF    = I.NRLANCTONF
                        AND I.NRSEQUMAPAPU IS NOT NULL
                        AND I.CDIMPOSTO     = IM.CDIMPOSTO
                        AND IM.CDIMPOSTONFE = '50'
                        AND IM.CDIMPOSTONFE = '50'
                        AND E.CDEMPRESA     = N.CDEMPRESA
                        AND N.CDCLIENTE     = EC.CDCLIENTE
                        AND EC.CDPAIS       = '0055'
                        AND EC.IDTPENDECLIE = 'P'
                        GROUP BY E.IDTPIJUREMPR,
                          E.NRINSJUREMPR
                        )
                      ) RE,
                      EMPRESA E
                    WHERE RE.NRINSCESTAB = E.NRINSJUREMPR";  
        
        $params = array(
            "V_VREXPORTACAO"   => $vrexportacao,
            "P_DTINICIAL"   => $dtinicial,
            "P_DTFINAL"     => $dtfinal,
            "P_CDEMPRESA"   => $cdEmpresa
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function selectEventoToUpdateRetificacao($nmevento ,$versao){
        $sql =  "SELECT  * FROM EVENTOREINF 
                    WHERE NMEVENTO = :NMEVENTO 
                    AND DSVERSAO = :DSVERSAO";
        
        $params = array(
            "NMEVENTO"   => $nmevento,
            "DSVERSAO"   => $versao,
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
        
    }
    
    public function updateVersaoRetificacao($nrenvio, $versao, $nrevento){
        
        $sql = "UPDATE ENVIOEVENTOREINF
                   SET NREVENTO       = :NREVENTO, 
                       DSVERSAO       = :DSVERSAO
                WHERE  NRENVIO         = :NRENVIO";
        
        $params = array(
            "NREVENTO"          => $nrevento,
            "DSVERSAO"          => $versao,
            "NRENVIO"          => $nrenvio,
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);       
    }
    
    public function buscardados($dadosEnvio){
        $sql =  "SELECT * FROM PARAMEMPREINF 
                    WHERE CDEMPRESA = :CDEMPRESA";
        
        $params = array(
            "CDEMPRESA"   => $dadosEnvio['CDEMPRESA']
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    
        return $std->fetch();
    }
    
}