function CalendarController($scope, ScreenService, EventChildPropagation, metaDataFactory, templateManager) {

	var dateFormat = $scope.field.dateFormat || moment().locale(window.lang).localeData().longDateFormat("L");
	var displayFormat = $scope.field.displayFormat || dateFormat;
	var emptyValue = displayFormat.replace(/[Y,M,D]/gi, '_');

	function getDisplayValueByValue(value){
		var inDisplayFormat = moment(value, displayFormat, true).isValid();
		var displayValue = inDisplayFormat ? value : moment(value, dateFormat).format(displayFormat);
		return displayValue;
	}

	function getValueByDisplayValue(displayValue){
		var inDateFormat = moment(displayValue, dateFormat, true).isValid();
		var value = inDateFormat ? displayValue : moment(displayValue, displayFormat).format(dateFormat);
		return value;
	}

	function clearFormattedDate(){
		$scope.formattedDate = '';
		templateManager.updateTemplate();
	}

	function getInitialValue(){
		var value = $scope.field.value();
		return value ? getDisplayValueByValue(value) : '';
	}

	$scope.formattedDate = getInitialValue();

	$scope.setEmptyValue = function(){
		$scope.formattedDate = emptyValue;
		templateManager.updateTemplate();
	};

	$scope.fillCurrentRow = function(element){
		$scope.fieldRow = getValueByDisplayValue(element.value);
		$scope.formattedDate = getDisplayValueByValue(element.value);
	};

	$scope.$watch('fieldRow', function(newValue){
		if(newValue){
			$scope.formattedDate = getDisplayValueByValue(newValue);
		} else {
			$scope.formattedDate = "";
		}
	});

	$scope.openField = function(fieldParam) {
		var field = fieldParam || $scope.field;
		if (!field || field.isReadOnly()) {
			return;
		}
		var widgetEvents = [{
			"name": "WidgetAfterMoveRow",
			"code": "args.owner.setSelected(args);",
			"id": 9999
		}];
		var calendarWidget = {
			"id": 0,
			"name": "Widget",
			"label": ScreenService.i18n(field.label),
			"template": "widget/calendar.html",
			"container": field.widget.container,
			"selectField": field,
			"isVisible": true,
			"popupNoBlock": false,
			"showDescriptionOrder": false,
			"dataSource": field.dataSource,
			"dataSourceFilter": field.dataSourceFilter,
			"todayText": field.todayText || ScreenService.i18n("Today"),
			"weekDays": field.weekDays,
			"monthNames": field.monthNames || moment.months(),
			"dateField": field.dateField,
			"titleField": field.titleField,
			"dateFormat": dateFormat,
			"fields": [],
			"field": field,
			"calendarMode": field.calendarMode,
			"actions": [{
				"label": ScreenService.i18n("Cancel"),
				"hideIcon": true,
				"showAsAction": "back",
				"isVisible": true,
				"showOnForm": true,
				"showOnList": true,
				"events": [{
					"name": "ActionEvent",
					"code": "ScreenService.closePopup()",
					"id": 9998
				}]
			}],
			"events": EventChildPropagation.propagate(widgetEvents, field)
		};
		field.calendarWidget = field.calendarWidget || metaDataFactory.widgetFactory(calendarWidget);

		if (field.maxDate) {
			field.calendarWidget.maxDate = field.maxDate;
		}

		if (field.minDate) {
			field.calendarWidget.minDate = field.minDate;
		}

		field.calendarWidget.setSelected = function(args) {
			ScreenService.closePopup();

			var field = args.owner.selectField;
			field.widget.currentRow[field.name] = args.row;
			field.useDateFormat = true;
			$scope.formattedDate = moment(args.row, dateFormat).format(displayFormat);
			templateManager.updateTemplate();

			if (field.change) {
				field.change();
			}

		};


		ScreenService.openPopup(field.calendarWidget);
	};

	var oldFieldValue = $scope.field.value;
	$scope.field.value = function(value) {
		if(!value){
			return $scope.field.widget.currentRow[$scope.field.name];
		}
		var dateFormat = $scope.field.dateFormat || "L";
		value = moment(value, dateFormat).format(dateFormat);
		$scope.field.widget.currentRow[$scope.field.name] = value;
	};

	$scope.field.openField = function() {
		$scope.openField($scope.field);
	};

	if ($scope.startField) {
		$scope.startField.openField = function() {
			$scope.openField($scope.startField);
		};
	}

	if ($scope.endField) {
		$scope.endField.openField = function() {
			$scope.openField($scope.endField);
		};
	}

	$scope.dateCompleted = function(element){
		$scope.formattedDate = getDisplayValueByValue(element[0].value);
	};

	$scope.clearField = function(fieldParam) {
		var field = fieldParam || $scope.field;
		if (field && !field.isReadOnly()) {
			clearFormattedDate();
			field.widget.currentRow[field.name] = "";
			field.currentDate = moment().startOf('month').startOf('day');
			if (field.change) {
				field.change();
			}
		}
	};

	$scope.field.clearValue = $scope.clearField;

	$scope.dynamicLongDateFormat = function() {
		return displayFormat.replace(/[D-Y]/g, '_');
	};

	$scope.$on("$destroy", function(){
		$scope.field.value = oldFieldValue;
	});
}